#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditEpSceneRatingInitializeModel(object):

    def __init__(self):
        self._apply_amount = None
        self._biz_ext_param = None
        self._credit_category = None
        self._ep_cert_no = None
        self._ep_name = None
        self._evaluate_type = None
        self._m_category = None
        self._member_type = None
        self._out_order_no = None
        self._product_code = None
        self._user_id = None

    @property
    def apply_amount(self):
        return self._apply_amount

    @apply_amount.setter
    def apply_amount(self, value):
        self._apply_amount = value
    @property
    def biz_ext_param(self):
        return self._biz_ext_param

    @biz_ext_param.setter
    def biz_ext_param(self, value):
        self._biz_ext_param = value
    @property
    def credit_category(self):
        return self._credit_category

    @credit_category.setter
    def credit_category(self, value):
        self._credit_category = value
    @property
    def ep_cert_no(self):
        return self._ep_cert_no

    @ep_cert_no.setter
    def ep_cert_no(self, value):
        self._ep_cert_no = value
    @property
    def ep_name(self):
        return self._ep_name

    @ep_name.setter
    def ep_name(self, value):
        self._ep_name = value
    @property
    def evaluate_type(self):
        return self._evaluate_type

    @evaluate_type.setter
    def evaluate_type(self, value):
        self._evaluate_type = value
    @property
    def m_category(self):
        return self._m_category

    @m_category.setter
    def m_category(self, value):
        self._m_category = value
    @property
    def member_type(self):
        return self._member_type

    @member_type.setter
    def member_type(self, value):
        self._member_type = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_amount:
            if hasattr(self.apply_amount, 'to_alipay_dict'):
                params['apply_amount'] = self.apply_amount.to_alipay_dict()
            else:
                params['apply_amount'] = self.apply_amount
        if self.biz_ext_param:
            if hasattr(self.biz_ext_param, 'to_alipay_dict'):
                params['biz_ext_param'] = self.biz_ext_param.to_alipay_dict()
            else:
                params['biz_ext_param'] = self.biz_ext_param
        if self.credit_category:
            if hasattr(self.credit_category, 'to_alipay_dict'):
                params['credit_category'] = self.credit_category.to_alipay_dict()
            else:
                params['credit_category'] = self.credit_category
        if self.ep_cert_no:
            if hasattr(self.ep_cert_no, 'to_alipay_dict'):
                params['ep_cert_no'] = self.ep_cert_no.to_alipay_dict()
            else:
                params['ep_cert_no'] = self.ep_cert_no
        if self.ep_name:
            if hasattr(self.ep_name, 'to_alipay_dict'):
                params['ep_name'] = self.ep_name.to_alipay_dict()
            else:
                params['ep_name'] = self.ep_name
        if self.evaluate_type:
            if hasattr(self.evaluate_type, 'to_alipay_dict'):
                params['evaluate_type'] = self.evaluate_type.to_alipay_dict()
            else:
                params['evaluate_type'] = self.evaluate_type
        if self.m_category:
            if hasattr(self.m_category, 'to_alipay_dict'):
                params['m_category'] = self.m_category.to_alipay_dict()
            else:
                params['m_category'] = self.m_category
        if self.member_type:
            if hasattr(self.member_type, 'to_alipay_dict'):
                params['member_type'] = self.member_type.to_alipay_dict()
            else:
                params['member_type'] = self.member_type
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditEpSceneRatingInitializeModel()
        if 'apply_amount' in d:
            o.apply_amount = d['apply_amount']
        if 'biz_ext_param' in d:
            o.biz_ext_param = d['biz_ext_param']
        if 'credit_category' in d:
            o.credit_category = d['credit_category']
        if 'ep_cert_no' in d:
            o.ep_cert_no = d['ep_cert_no']
        if 'ep_name' in d:
            o.ep_name = d['ep_name']
        if 'evaluate_type' in d:
            o.evaluate_type = d['evaluate_type']
        if 'm_category' in d:
            o.m_category = d['m_category']
        if 'member_type' in d:
            o.member_type = d['member_type']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SignInfo(object):

    def __init__(self):
        self._back_url = None
        self._ext_info = None
        self._inst_id = None
        self._sign_product_id = None
        self._signer_name = None
        self._solution_code = None

    @property
    def back_url(self):
        return self._back_url

    @back_url.setter
    def back_url(self, value):
        self._back_url = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def sign_product_id(self):
        return self._sign_product_id

    @sign_product_id.setter
    def sign_product_id(self, value):
        self._sign_product_id = value
    @property
    def signer_name(self):
        return self._signer_name

    @signer_name.setter
    def signer_name(self, value):
        self._signer_name = value
    @property
    def solution_code(self):
        return self._solution_code

    @solution_code.setter
    def solution_code(self, value):
        self._solution_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.back_url:
            if hasattr(self.back_url, 'to_alipay_dict'):
                params['back_url'] = self.back_url.to_alipay_dict()
            else:
                params['back_url'] = self.back_url
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.sign_product_id:
            if hasattr(self.sign_product_id, 'to_alipay_dict'):
                params['sign_product_id'] = self.sign_product_id.to_alipay_dict()
            else:
                params['sign_product_id'] = self.sign_product_id
        if self.signer_name:
            if hasattr(self.signer_name, 'to_alipay_dict'):
                params['signer_name'] = self.signer_name.to_alipay_dict()
            else:
                params['signer_name'] = self.signer_name
        if self.solution_code:
            if hasattr(self.solution_code, 'to_alipay_dict'):
                params['solution_code'] = self.solution_code.to_alipay_dict()
            else:
                params['solution_code'] = self.solution_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SignInfo()
        if 'back_url' in d:
            o.back_url = d['back_url']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'sign_product_id' in d:
            o.sign_product_id = d['sign_product_id']
        if 'signer_name' in d:
            o.signer_name = d['signer_name']
        if 'solution_code' in d:
            o.solution_code = d['solution_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.FaceExtParams import FaceExtParams
from alipay.aop.api.domain.FaceMachineInfo import FaceMachineInfo
from alipay.aop.api.domain.FaceMerchantInfo import FaceMerchantInfo


class ZolozAuthenticationSmilepayInitializeModel(object):

    def __init__(self):
        self._apdid_token = None
        self._app_name = None
        self._app_version = None
        self._base_ver = None
        self._bio_meta_info = None
        self._device_model = None
        self._device_type = None
        self._ext_info = None
        self._machine_info = None
        self._merchant_info = None
        self._os_version = None
        self._remote_log_id = None
        self._zim_ver = None

    @property
    def apdid_token(self):
        return self._apdid_token

    @apdid_token.setter
    def apdid_token(self, value):
        self._apdid_token = value
    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def app_version(self):
        return self._app_version

    @app_version.setter
    def app_version(self, value):
        self._app_version = value
    @property
    def base_ver(self):
        return self._base_ver

    @base_ver.setter
    def base_ver(self, value):
        self._base_ver = value
    @property
    def bio_meta_info(self):
        return self._bio_meta_info

    @bio_meta_info.setter
    def bio_meta_info(self, value):
        self._bio_meta_info = value
    @property
    def device_model(self):
        return self._device_model

    @device_model.setter
    def device_model(self, value):
        self._device_model = value
    @property
    def device_type(self):
        return self._device_type

    @device_type.setter
    def device_type(self, value):
        self._device_type = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        if isinstance(value, FaceExtParams):
            self._ext_info = value
        else:
            self._ext_info = FaceExtParams.from_alipay_dict(value)
    @property
    def machine_info(self):
        return self._machine_info

    @machine_info.setter
    def machine_info(self, value):
        if isinstance(value, FaceMachineInfo):
            self._machine_info = value
        else:
            self._machine_info = FaceMachineInfo.from_alipay_dict(value)
    @property
    def merchant_info(self):
        return self._merchant_info

    @merchant_info.setter
    def merchant_info(self, value):
        if isinstance(value, FaceMerchantInfo):
            self._merchant_info = value
        else:
            self._merchant_info = FaceMerchantInfo.from_alipay_dict(value)
    @property
    def os_version(self):
        return self._os_version

    @os_version.setter
    def os_version(self, value):
        self._os_version = value
    @property
    def remote_log_id(self):
        return self._remote_log_id

    @remote_log_id.setter
    def remote_log_id(self, value):
        self._remote_log_id = value
    @property
    def zim_ver(self):
        return self._zim_ver

    @zim_ver.setter
    def zim_ver(self, value):
        self._zim_ver = value


    def to_alipay_dict(self):
        params = dict()
        if self.apdid_token:
            if hasattr(self.apdid_token, 'to_alipay_dict'):
                params['apdid_token'] = self.apdid_token.to_alipay_dict()
            else:
                params['apdid_token'] = self.apdid_token
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.app_version:
            if hasattr(self.app_version, 'to_alipay_dict'):
                params['app_version'] = self.app_version.to_alipay_dict()
            else:
                params['app_version'] = self.app_version
        if self.base_ver:
            if hasattr(self.base_ver, 'to_alipay_dict'):
                params['base_ver'] = self.base_ver.to_alipay_dict()
            else:
                params['base_ver'] = self.base_ver
        if self.bio_meta_info:
            if hasattr(self.bio_meta_info, 'to_alipay_dict'):
                params['bio_meta_info'] = self.bio_meta_info.to_alipay_dict()
            else:
                params['bio_meta_info'] = self.bio_meta_info
        if self.device_model:
            if hasattr(self.device_model, 'to_alipay_dict'):
                params['device_model'] = self.device_model.to_alipay_dict()
            else:
                params['device_model'] = self.device_model
        if self.device_type:
            if hasattr(self.device_type, 'to_alipay_dict'):
                params['device_type'] = self.device_type.to_alipay_dict()
            else:
                params['device_type'] = self.device_type
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.machine_info:
            if hasattr(self.machine_info, 'to_alipay_dict'):
                params['machine_info'] = self.machine_info.to_alipay_dict()
            else:
                params['machine_info'] = self.machine_info
        if self.merchant_info:
            if hasattr(self.merchant_info, 'to_alipay_dict'):
                params['merchant_info'] = self.merchant_info.to_alipay_dict()
            else:
                params['merchant_info'] = self.merchant_info
        if self.os_version:
            if hasattr(self.os_version, 'to_alipay_dict'):
                params['os_version'] = self.os_version.to_alipay_dict()
            else:
                params['os_version'] = self.os_version
        if self.remote_log_id:
            if hasattr(self.remote_log_id, 'to_alipay_dict'):
                params['remote_log_id'] = self.remote_log_id.to_alipay_dict()
            else:
                params['remote_log_id'] = self.remote_log_id
        if self.zim_ver:
            if hasattr(self.zim_ver, 'to_alipay_dict'):
                params['zim_ver'] = self.zim_ver.to_alipay_dict()
            else:
                params['zim_ver'] = self.zim_ver
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZolozAuthenticationSmilepayInitializeModel()
        if 'apdid_token' in d:
            o.apdid_token = d['apdid_token']
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'app_version' in d:
            o.app_version = d['app_version']
        if 'base_ver' in d:
            o.base_ver = d['base_ver']
        if 'bio_meta_info' in d:
            o.bio_meta_info = d['bio_meta_info']
        if 'device_model' in d:
            o.device_model = d['device_model']
        if 'device_type' in d:
            o.device_type = d['device_type']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'machine_info' in d:
            o.machine_info = d['machine_info']
        if 'merchant_info' in d:
            o.merchant_info = d['merchant_info']
        if 'os_version' in d:
            o.os_version = d['os_version']
        if 'remote_log_id' in d:
            o.remote_log_id = d['remote_log_id']
        if 'zim_ver' in d:
            o.zim_ver = d['zim_ver']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MaterialCreateInfo import MaterialCreateInfo


class AntMerchantExpandFrontcategorySecurityCreateModel(object):

    def __init__(self):
        self._description = None
        self._material_list = None
        self._name = None
        self._scene = None
        self._target_id = None
        self._target_type = None

    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def material_list(self):
        return self._material_list

    @material_list.setter
    def material_list(self, value):
        if isinstance(value, list):
            self._material_list = list()
            for i in value:
                if isinstance(i, MaterialCreateInfo):
                    self._material_list.append(i)
                else:
                    self._material_list.append(MaterialCreateInfo.from_alipay_dict(i))
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value
    @property
    def target_id(self):
        return self._target_id

    @target_id.setter
    def target_id(self, value):
        self._target_id = value
    @property
    def target_type(self):
        return self._target_type

    @target_type.setter
    def target_type(self, value):
        self._target_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.material_list:
            if isinstance(self.material_list, list):
                for i in range(0, len(self.material_list)):
                    element = self.material_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.material_list[i] = element.to_alipay_dict()
            if hasattr(self.material_list, 'to_alipay_dict'):
                params['material_list'] = self.material_list.to_alipay_dict()
            else:
                params['material_list'] = self.material_list
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        if self.target_id:
            if hasattr(self.target_id, 'to_alipay_dict'):
                params['target_id'] = self.target_id.to_alipay_dict()
            else:
                params['target_id'] = self.target_id
        if self.target_type:
            if hasattr(self.target_type, 'to_alipay_dict'):
                params['target_type'] = self.target_type.to_alipay_dict()
            else:
                params['target_type'] = self.target_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandFrontcategorySecurityCreateModel()
        if 'description' in d:
            o.description = d['description']
        if 'material_list' in d:
            o.material_list = d['material_list']
        if 'name' in d:
            o.name = d['name']
        if 'scene' in d:
            o.scene = d['scene']
        if 'target_id' in d:
            o.target_id = d['target_id']
        if 'target_type' in d:
            o.target_type = d['target_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TicketInfo(object):

    def __init__(self):
        self._address = None
        self._end_time = None
        self._resv_type = None
        self._shop = None
        self._ticket_no = None
        self._time = None
        self._type = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def resv_type(self):
        return self._resv_type

    @resv_type.setter
    def resv_type(self, value):
        self._resv_type = value
    @property
    def shop(self):
        return self._shop

    @shop.setter
    def shop(self, value):
        self._shop = value
    @property
    def ticket_no(self):
        return self._ticket_no

    @ticket_no.setter
    def ticket_no(self, value):
        self._ticket_no = value
    @property
    def time(self):
        return self._time

    @time.setter
    def time(self, value):
        self._time = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.resv_type:
            if hasattr(self.resv_type, 'to_alipay_dict'):
                params['resv_type'] = self.resv_type.to_alipay_dict()
            else:
                params['resv_type'] = self.resv_type
        if self.shop:
            if hasattr(self.shop, 'to_alipay_dict'):
                params['shop'] = self.shop.to_alipay_dict()
            else:
                params['shop'] = self.shop
        if self.ticket_no:
            if hasattr(self.ticket_no, 'to_alipay_dict'):
                params['ticket_no'] = self.ticket_no.to_alipay_dict()
            else:
                params['ticket_no'] = self.ticket_no
        if self.time:
            if hasattr(self.time, 'to_alipay_dict'):
                params['time'] = self.time.to_alipay_dict()
            else:
                params['time'] = self.time
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TicketInfo()
        if 'address' in d:
            o.address = d['address']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'resv_type' in d:
            o.resv_type = d['resv_type']
        if 'shop' in d:
            o.shop = d['shop']
        if 'ticket_no' in d:
            o.ticket_no = d['ticket_no']
        if 'time' in d:
            o.time = d['time']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MiniAppBaseInfoQueryInfo import MiniAppBaseInfoQueryInfo


class AlipayOpenMiniInnerbaseinfoBatchqueryModel(object):

    def __init__(self):
        self._inst_code = None
        self._mini_app_id_list = None

    @property
    def inst_code(self):
        return self._inst_code

    @inst_code.setter
    def inst_code(self, value):
        self._inst_code = value
    @property
    def mini_app_id_list(self):
        return self._mini_app_id_list

    @mini_app_id_list.setter
    def mini_app_id_list(self, value):
        if isinstance(value, list):
            self._mini_app_id_list = list()
            for i in value:
                if isinstance(i, MiniAppBaseInfoQueryInfo):
                    self._mini_app_id_list.append(i)
                else:
                    self._mini_app_id_list.append(MiniAppBaseInfoQueryInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.inst_code:
            if hasattr(self.inst_code, 'to_alipay_dict'):
                params['inst_code'] = self.inst_code.to_alipay_dict()
            else:
                params['inst_code'] = self.inst_code
        if self.mini_app_id_list:
            if isinstance(self.mini_app_id_list, list):
                for i in range(0, len(self.mini_app_id_list)):
                    element = self.mini_app_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.mini_app_id_list[i] = element.to_alipay_dict()
            if hasattr(self.mini_app_id_list, 'to_alipay_dict'):
                params['mini_app_id_list'] = self.mini_app_id_list.to_alipay_dict()
            else:
                params['mini_app_id_list'] = self.mini_app_id_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniInnerbaseinfoBatchqueryModel()
        if 'inst_code' in d:
            o.inst_code = d['inst_code']
        if 'mini_app_id_list' in d:
            o.mini_app_id_list = d['mini_app_id_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceMedicalInstcardCreateandpayModel(object):

    def __init__(self):
        self._bill_no = None
        self._body = None
        self._buyer_id = None
        self._extend_params = None
        self._gmt_out_create = None
        self._industry = None
        self._is_insurance = None
        self._medical_card_id = None
        self._medical_card_inst_id = None
        self._org_name = None
        self._org_no = None
        self._out_trade_no = None
        self._patient_card_no = None
        self._patient_card_type = None
        self._patient_mobile = None
        self._patient_name = None
        self._request_content = None
        self._scene = None
        self._seller_id = None
        self._serial_no = None
        self._subject = None
        self._timeout_express = None
        self._total_amount = None

    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def body(self):
        return self._body

    @body.setter
    def body(self, value):
        self._body = value
    @property
    def buyer_id(self):
        return self._buyer_id

    @buyer_id.setter
    def buyer_id(self, value):
        self._buyer_id = value
    @property
    def extend_params(self):
        return self._extend_params

    @extend_params.setter
    def extend_params(self, value):
        self._extend_params = value
    @property
    def gmt_out_create(self):
        return self._gmt_out_create

    @gmt_out_create.setter
    def gmt_out_create(self, value):
        self._gmt_out_create = value
    @property
    def industry(self):
        return self._industry

    @industry.setter
    def industry(self, value):
        self._industry = value
    @property
    def is_insurance(self):
        return self._is_insurance

    @is_insurance.setter
    def is_insurance(self, value):
        self._is_insurance = value
    @property
    def medical_card_id(self):
        return self._medical_card_id

    @medical_card_id.setter
    def medical_card_id(self, value):
        self._medical_card_id = value
    @property
    def medical_card_inst_id(self):
        return self._medical_card_inst_id

    @medical_card_inst_id.setter
    def medical_card_inst_id(self, value):
        self._medical_card_inst_id = value
    @property
    def org_name(self):
        return self._org_name

    @org_name.setter
    def org_name(self, value):
        self._org_name = value
    @property
    def org_no(self):
        return self._org_no

    @org_no.setter
    def org_no(self, value):
        self._org_no = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def patient_card_no(self):
        return self._patient_card_no

    @patient_card_no.setter
    def patient_card_no(self, value):
        self._patient_card_no = value
    @property
    def patient_card_type(self):
        return self._patient_card_type

    @patient_card_type.setter
    def patient_card_type(self, value):
        self._patient_card_type = value
    @property
    def patient_mobile(self):
        return self._patient_mobile

    @patient_mobile.setter
    def patient_mobile(self, value):
        self._patient_mobile = value
    @property
    def patient_name(self):
        return self._patient_name

    @patient_name.setter
    def patient_name(self, value):
        self._patient_name = value
    @property
    def request_content(self):
        return self._request_content

    @request_content.setter
    def request_content(self, value):
        self._request_content = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def serial_no(self):
        return self._serial_no

    @serial_no.setter
    def serial_no(self, value):
        self._serial_no = value
    @property
    def subject(self):
        return self._subject

    @subject.setter
    def subject(self, value):
        self._subject = value
    @property
    def timeout_express(self):
        return self._timeout_express

    @timeout_express.setter
    def timeout_express(self, value):
        self._timeout_express = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.bill_no:
            if hasattr(self.bill_no, 'to_alipay_dict'):
                params['bill_no'] = self.bill_no.to_alipay_dict()
            else:
                params['bill_no'] = self.bill_no
        if self.body:
            if hasattr(self.body, 'to_alipay_dict'):
                params['body'] = self.body.to_alipay_dict()
            else:
                params['body'] = self.body
        if self.buyer_id:
            if hasattr(self.buyer_id, 'to_alipay_dict'):
                params['buyer_id'] = self.buyer_id.to_alipay_dict()
            else:
                params['buyer_id'] = self.buyer_id
        if self.extend_params:
            if hasattr(self.extend_params, 'to_alipay_dict'):
                params['extend_params'] = self.extend_params.to_alipay_dict()
            else:
                params['extend_params'] = self.extend_params
        if self.gmt_out_create:
            if hasattr(self.gmt_out_create, 'to_alipay_dict'):
                params['gmt_out_create'] = self.gmt_out_create.to_alipay_dict()
            else:
                params['gmt_out_create'] = self.gmt_out_create
        if self.industry:
            if hasattr(self.industry, 'to_alipay_dict'):
                params['industry'] = self.industry.to_alipay_dict()
            else:
                params['industry'] = self.industry
        if self.is_insurance:
            if hasattr(self.is_insurance, 'to_alipay_dict'):
                params['is_insurance'] = self.is_insurance.to_alipay_dict()
            else:
                params['is_insurance'] = self.is_insurance
        if self.medical_card_id:
            if hasattr(self.medical_card_id, 'to_alipay_dict'):
                params['medical_card_id'] = self.medical_card_id.to_alipay_dict()
            else:
                params['medical_card_id'] = self.medical_card_id
        if self.medical_card_inst_id:
            if hasattr(self.medical_card_inst_id, 'to_alipay_dict'):
                params['medical_card_inst_id'] = self.medical_card_inst_id.to_alipay_dict()
            else:
                params['medical_card_inst_id'] = self.medical_card_inst_id
        if self.org_name:
            if hasattr(self.org_name, 'to_alipay_dict'):
                params['org_name'] = self.org_name.to_alipay_dict()
            else:
                params['org_name'] = self.org_name
        if self.org_no:
            if hasattr(self.org_no, 'to_alipay_dict'):
                params['org_no'] = self.org_no.to_alipay_dict()
            else:
                params['org_no'] = self.org_no
        if self.out_trade_no:
            if hasattr(self.out_trade_no, 'to_alipay_dict'):
                params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
            else:
                params['out_trade_no'] = self.out_trade_no
        if self.patient_card_no:
            if hasattr(self.patient_card_no, 'to_alipay_dict'):
                params['patient_card_no'] = self.patient_card_no.to_alipay_dict()
            else:
                params['patient_card_no'] = self.patient_card_no
        if self.patient_card_type:
            if hasattr(self.patient_card_type, 'to_alipay_dict'):
                params['patient_card_type'] = self.patient_card_type.to_alipay_dict()
            else:
                params['patient_card_type'] = self.patient_card_type
        if self.patient_mobile:
            if hasattr(self.patient_mobile, 'to_alipay_dict'):
                params['patient_mobile'] = self.patient_mobile.to_alipay_dict()
            else:
                params['patient_mobile'] = self.patient_mobile
        if self.patient_name:
            if hasattr(self.patient_name, 'to_alipay_dict'):
                params['patient_name'] = self.patient_name.to_alipay_dict()
            else:
                params['patient_name'] = self.patient_name
        if self.request_content:
            if hasattr(self.request_content, 'to_alipay_dict'):
                params['request_content'] = self.request_content.to_alipay_dict()
            else:
                params['request_content'] = self.request_content
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        if self.seller_id:
            if hasattr(self.seller_id, 'to_alipay_dict'):
                params['seller_id'] = self.seller_id.to_alipay_dict()
            else:
                params['seller_id'] = self.seller_id
        if self.serial_no:
            if hasattr(self.serial_no, 'to_alipay_dict'):
                params['serial_no'] = self.serial_no.to_alipay_dict()
            else:
                params['serial_no'] = self.serial_no
        if self.subject:
            if hasattr(self.subject, 'to_alipay_dict'):
                params['subject'] = self.subject.to_alipay_dict()
            else:
                params['subject'] = self.subject
        if self.timeout_express:
            if hasattr(self.timeout_express, 'to_alipay_dict'):
                params['timeout_express'] = self.timeout_express.to_alipay_dict()
            else:
                params['timeout_express'] = self.timeout_express
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceMedicalInstcardCreateandpayModel()
        if 'bill_no' in d:
            o.bill_no = d['bill_no']
        if 'body' in d:
            o.body = d['body']
        if 'buyer_id' in d:
            o.buyer_id = d['buyer_id']
        if 'extend_params' in d:
            o.extend_params = d['extend_params']
        if 'gmt_out_create' in d:
            o.gmt_out_create = d['gmt_out_create']
        if 'industry' in d:
            o.industry = d['industry']
        if 'is_insurance' in d:
            o.is_insurance = d['is_insurance']
        if 'medical_card_id' in d:
            o.medical_card_id = d['medical_card_id']
        if 'medical_card_inst_id' in d:
            o.medical_card_inst_id = d['medical_card_inst_id']
        if 'org_name' in d:
            o.org_name = d['org_name']
        if 'org_no' in d:
            o.org_no = d['org_no']
        if 'out_trade_no' in d:
            o.out_trade_no = d['out_trade_no']
        if 'patient_card_no' in d:
            o.patient_card_no = d['patient_card_no']
        if 'patient_card_type' in d:
            o.patient_card_type = d['patient_card_type']
        if 'patient_mobile' in d:
            o.patient_mobile = d['patient_mobile']
        if 'patient_name' in d:
            o.patient_name = d['patient_name']
        if 'request_content' in d:
            o.request_content = d['request_content']
        if 'scene' in d:
            o.scene = d['scene']
        if 'seller_id' in d:
            o.seller_id = d['seller_id']
        if 'serial_no' in d:
            o.serial_no = d['serial_no']
        if 'subject' in d:
            o.subject = d['subject']
        if 'timeout_express' in d:
            o.timeout_express = d['timeout_express']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.JointAccountQuotaDTO import JointAccountQuotaDTO
from alipay.aop.api.domain.AuthorizeDetailDTO import AuthorizeDetailDTO
from alipay.aop.api.domain.AuthorizedRuleDTO import AuthorizedRuleDTO
from alipay.aop.api.domain.InviteMemberForm import InviteMemberForm


class AlipayFundJointaccountSignModel(object):

    def __init__(self):
        self._account_name = None
        self._account_quota = None
        self._authorized_detail_list = None
        self._authorized_rule = None
        self._biz_scene = None
        self._identity = None
        self._identity_type = None
        self._invitee_list = None
        self._name = None
        self._open_timeout = None
        self._out_biz_no = None
        self._out_entity_id = None
        self._out_source = None
        self._product_code = None

    @property
    def account_name(self):
        return self._account_name

    @account_name.setter
    def account_name(self, value):
        self._account_name = value
    @property
    def account_quota(self):
        return self._account_quota

    @account_quota.setter
    def account_quota(self, value):
        if isinstance(value, list):
            self._account_quota = list()
            for i in value:
                if isinstance(i, JointAccountQuotaDTO):
                    self._account_quota.append(i)
                else:
                    self._account_quota.append(JointAccountQuotaDTO.from_alipay_dict(i))
    @property
    def authorized_detail_list(self):
        return self._authorized_detail_list

    @authorized_detail_list.setter
    def authorized_detail_list(self, value):
        if isinstance(value, list):
            self._authorized_detail_list = list()
            for i in value:
                if isinstance(i, AuthorizeDetailDTO):
                    self._authorized_detail_list.append(i)
                else:
                    self._authorized_detail_list.append(AuthorizeDetailDTO.from_alipay_dict(i))
    @property
    def authorized_rule(self):
        return self._authorized_rule

    @authorized_rule.setter
    def authorized_rule(self, value):
        if isinstance(value, AuthorizedRuleDTO):
            self._authorized_rule = value
        else:
            self._authorized_rule = AuthorizedRuleDTO.from_alipay_dict(value)
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def identity(self):
        return self._identity

    @identity.setter
    def identity(self, value):
        self._identity = value
    @property
    def identity_type(self):
        return self._identity_type

    @identity_type.setter
    def identity_type(self, value):
        self._identity_type = value
    @property
    def invitee_list(self):
        return self._invitee_list

    @invitee_list.setter
    def invitee_list(self, value):
        if isinstance(value, list):
            self._invitee_list = list()
            for i in value:
                if isinstance(i, InviteMemberForm):
                    self._invitee_list.append(i)
                else:
                    self._invitee_list.append(InviteMemberForm.from_alipay_dict(i))
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def open_timeout(self):
        return self._open_timeout

    @open_timeout.setter
    def open_timeout(self, value):
        self._open_timeout = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def out_entity_id(self):
        return self._out_entity_id

    @out_entity_id.setter
    def out_entity_id(self, value):
        self._out_entity_id = value
    @property
    def out_source(self):
        return self._out_source

    @out_source.setter
    def out_source(self, value):
        self._out_source = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_name:
            if hasattr(self.account_name, 'to_alipay_dict'):
                params['account_name'] = self.account_name.to_alipay_dict()
            else:
                params['account_name'] = self.account_name
        if self.account_quota:
            if isinstance(self.account_quota, list):
                for i in range(0, len(self.account_quota)):
                    element = self.account_quota[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.account_quota[i] = element.to_alipay_dict()
            if hasattr(self.account_quota, 'to_alipay_dict'):
                params['account_quota'] = self.account_quota.to_alipay_dict()
            else:
                params['account_quota'] = self.account_quota
        if self.authorized_detail_list:
            if isinstance(self.authorized_detail_list, list):
                for i in range(0, len(self.authorized_detail_list)):
                    element = self.authorized_detail_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.authorized_detail_list[i] = element.to_alipay_dict()
            if hasattr(self.authorized_detail_list, 'to_alipay_dict'):
                params['authorized_detail_list'] = self.authorized_detail_list.to_alipay_dict()
            else:
                params['authorized_detail_list'] = self.authorized_detail_list
        if self.authorized_rule:
            if hasattr(self.authorized_rule, 'to_alipay_dict'):
                params['authorized_rule'] = self.authorized_rule.to_alipay_dict()
            else:
                params['authorized_rule'] = self.authorized_rule
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.identity:
            if hasattr(self.identity, 'to_alipay_dict'):
                params['identity'] = self.identity.to_alipay_dict()
            else:
                params['identity'] = self.identity
        if self.identity_type:
            if hasattr(self.identity_type, 'to_alipay_dict'):
                params['identity_type'] = self.identity_type.to_alipay_dict()
            else:
                params['identity_type'] = self.identity_type
        if self.invitee_list:
            if isinstance(self.invitee_list, list):
                for i in range(0, len(self.invitee_list)):
                    element = self.invitee_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.invitee_list[i] = element.to_alipay_dict()
            if hasattr(self.invitee_list, 'to_alipay_dict'):
                params['invitee_list'] = self.invitee_list.to_alipay_dict()
            else:
                params['invitee_list'] = self.invitee_list
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.open_timeout:
            if hasattr(self.open_timeout, 'to_alipay_dict'):
                params['open_timeout'] = self.open_timeout.to_alipay_dict()
            else:
                params['open_timeout'] = self.open_timeout
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.out_entity_id:
            if hasattr(self.out_entity_id, 'to_alipay_dict'):
                params['out_entity_id'] = self.out_entity_id.to_alipay_dict()
            else:
                params['out_entity_id'] = self.out_entity_id
        if self.out_source:
            if hasattr(self.out_source, 'to_alipay_dict'):
                params['out_source'] = self.out_source.to_alipay_dict()
            else:
                params['out_source'] = self.out_source
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundJointaccountSignModel()
        if 'account_name' in d:
            o.account_name = d['account_name']
        if 'account_quota' in d:
            o.account_quota = d['account_quota']
        if 'authorized_detail_list' in d:
            o.authorized_detail_list = d['authorized_detail_list']
        if 'authorized_rule' in d:
            o.authorized_rule = d['authorized_rule']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'identity' in d:
            o.identity = d['identity']
        if 'identity_type' in d:
            o.identity_type = d['identity_type']
        if 'invitee_list' in d:
            o.invitee_list = d['invitee_list']
        if 'name' in d:
            o.name = d['name']
        if 'open_timeout' in d:
            o.open_timeout = d['open_timeout']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'out_entity_id' in d:
            o.out_entity_id = d['out_entity_id']
        if 'out_source' in d:
            o.out_source = d['out_source']
        if 'product_code' in d:
            o.product_code = d['product_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TuitionUserName import TuitionUserName
from alipay.aop.api.domain.TuitionAddress import TuitionAddress


class TuitionBankAccountDetail(object):

    def __init__(self):
        self._bank_account_no = None
        self._bank_bic = None
        self._bank_name = None
        self._holder_account_name = None
        self._holder_address = None
        self._routing_number = None

    @property
    def bank_account_no(self):
        return self._bank_account_no

    @bank_account_no.setter
    def bank_account_no(self, value):
        self._bank_account_no = value
    @property
    def bank_bic(self):
        return self._bank_bic

    @bank_bic.setter
    def bank_bic(self, value):
        self._bank_bic = value
    @property
    def bank_name(self):
        return self._bank_name

    @bank_name.setter
    def bank_name(self, value):
        self._bank_name = value
    @property
    def holder_account_name(self):
        return self._holder_account_name

    @holder_account_name.setter
    def holder_account_name(self, value):
        if isinstance(value, TuitionUserName):
            self._holder_account_name = value
        else:
            self._holder_account_name = TuitionUserName.from_alipay_dict(value)
    @property
    def holder_address(self):
        return self._holder_address

    @holder_address.setter
    def holder_address(self, value):
        if isinstance(value, TuitionAddress):
            self._holder_address = value
        else:
            self._holder_address = TuitionAddress.from_alipay_dict(value)
    @property
    def routing_number(self):
        return self._routing_number

    @routing_number.setter
    def routing_number(self, value):
        self._routing_number = value


    def to_alipay_dict(self):
        params = dict()
        if self.bank_account_no:
            if hasattr(self.bank_account_no, 'to_alipay_dict'):
                params['bank_account_no'] = self.bank_account_no.to_alipay_dict()
            else:
                params['bank_account_no'] = self.bank_account_no
        if self.bank_bic:
            if hasattr(self.bank_bic, 'to_alipay_dict'):
                params['bank_bic'] = self.bank_bic.to_alipay_dict()
            else:
                params['bank_bic'] = self.bank_bic
        if self.bank_name:
            if hasattr(self.bank_name, 'to_alipay_dict'):
                params['bank_name'] = self.bank_name.to_alipay_dict()
            else:
                params['bank_name'] = self.bank_name
        if self.holder_account_name:
            if hasattr(self.holder_account_name, 'to_alipay_dict'):
                params['holder_account_name'] = self.holder_account_name.to_alipay_dict()
            else:
                params['holder_account_name'] = self.holder_account_name
        if self.holder_address:
            if hasattr(self.holder_address, 'to_alipay_dict'):
                params['holder_address'] = self.holder_address.to_alipay_dict()
            else:
                params['holder_address'] = self.holder_address
        if self.routing_number:
            if hasattr(self.routing_number, 'to_alipay_dict'):
                params['routing_number'] = self.routing_number.to_alipay_dict()
            else:
                params['routing_number'] = self.routing_number
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TuitionBankAccountDetail()
        if 'bank_account_no' in d:
            o.bank_account_no = d['bank_account_no']
        if 'bank_bic' in d:
            o.bank_bic = d['bank_bic']
        if 'bank_name' in d:
            o.bank_name = d['bank_name']
        if 'holder_account_name' in d:
            o.holder_account_name = d['holder_account_name']
        if 'holder_address' in d:
            o.holder_address = d['holder_address']
        if 'routing_number' in d:
            o.routing_number = d['routing_number']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CreditPayDayRangePricingVO(object):

    def __init__(self):
        self._end_date = None
        self._int_rate = None
        self._interest = None
        self._start_date = None

    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def int_rate(self):
        return self._int_rate

    @int_rate.setter
    def int_rate(self, value):
        self._int_rate = value
    @property
    def interest(self):
        return self._interest

    @interest.setter
    def interest(self, value):
        self._interest = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.int_rate:
            if hasattr(self.int_rate, 'to_alipay_dict'):
                params['int_rate'] = self.int_rate.to_alipay_dict()
            else:
                params['int_rate'] = self.int_rate
        if self.interest:
            if hasattr(self.interest, 'to_alipay_dict'):
                params['interest'] = self.interest.to_alipay_dict()
            else:
                params['interest'] = self.interest
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CreditPayDayRangePricingVO()
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'int_rate' in d:
            o.int_rate = d['int_rate']
        if 'interest' in d:
            o.interest = d['interest']
        if 'start_date' in d:
            o.start_date = d['start_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserVirtualcardSignEffectModel(object):

    def __init__(self):
        self._card_data = None
        self._card_no = None
        self._card_type = None
        self._disabled = None
        self._disabled_tips = None
        self._disabled_url = None
        self._ext_info = None
        self._user_id = None

    @property
    def card_data(self):
        return self._card_data

    @card_data.setter
    def card_data(self, value):
        self._card_data = value
    @property
    def card_no(self):
        return self._card_no

    @card_no.setter
    def card_no(self, value):
        self._card_no = value
    @property
    def card_type(self):
        return self._card_type

    @card_type.setter
    def card_type(self, value):
        self._card_type = value
    @property
    def disabled(self):
        return self._disabled

    @disabled.setter
    def disabled(self, value):
        self._disabled = value
    @property
    def disabled_tips(self):
        return self._disabled_tips

    @disabled_tips.setter
    def disabled_tips(self, value):
        self._disabled_tips = value
    @property
    def disabled_url(self):
        return self._disabled_url

    @disabled_url.setter
    def disabled_url(self, value):
        self._disabled_url = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.card_data:
            if hasattr(self.card_data, 'to_alipay_dict'):
                params['card_data'] = self.card_data.to_alipay_dict()
            else:
                params['card_data'] = self.card_data
        if self.card_no:
            if hasattr(self.card_no, 'to_alipay_dict'):
                params['card_no'] = self.card_no.to_alipay_dict()
            else:
                params['card_no'] = self.card_no
        if self.card_type:
            if hasattr(self.card_type, 'to_alipay_dict'):
                params['card_type'] = self.card_type.to_alipay_dict()
            else:
                params['card_type'] = self.card_type
        if self.disabled:
            if hasattr(self.disabled, 'to_alipay_dict'):
                params['disabled'] = self.disabled.to_alipay_dict()
            else:
                params['disabled'] = self.disabled
        if self.disabled_tips:
            if hasattr(self.disabled_tips, 'to_alipay_dict'):
                params['disabled_tips'] = self.disabled_tips.to_alipay_dict()
            else:
                params['disabled_tips'] = self.disabled_tips
        if self.disabled_url:
            if hasattr(self.disabled_url, 'to_alipay_dict'):
                params['disabled_url'] = self.disabled_url.to_alipay_dict()
            else:
                params['disabled_url'] = self.disabled_url
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserVirtualcardSignEffectModel()
        if 'card_data' in d:
            o.card_data = d['card_data']
        if 'card_no' in d:
            o.card_no = d['card_no']
        if 'card_type' in d:
            o.card_type = d['card_type']
        if 'disabled' in d:
            o.disabled = d['disabled']
        if 'disabled_tips' in d:
            o.disabled_tips = d['disabled_tips']
        if 'disabled_url' in d:
            o.disabled_url = d['disabled_url']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OfflineInviteNewerDetailInfo(object):

    def __init__(self):
        self._city_name = None
        self._ext_info = None
        self._invited_phone = None
        self._lbs_rate = None
        self._partner_id = None
        self._pid = None
        self._province_name = None
        self._settled = None
        self._settled_and_bind = None
        self._user_bind_card_time = None
        self._user_cert_time = None
        self._user_prize_time = None

    @property
    def city_name(self):
        return self._city_name

    @city_name.setter
    def city_name(self, value):
        self._city_name = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def invited_phone(self):
        return self._invited_phone

    @invited_phone.setter
    def invited_phone(self, value):
        self._invited_phone = value
    @property
    def lbs_rate(self):
        return self._lbs_rate

    @lbs_rate.setter
    def lbs_rate(self, value):
        self._lbs_rate = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def province_name(self):
        return self._province_name

    @province_name.setter
    def province_name(self, value):
        self._province_name = value
    @property
    def settled(self):
        return self._settled

    @settled.setter
    def settled(self, value):
        self._settled = value
    @property
    def settled_and_bind(self):
        return self._settled_and_bind

    @settled_and_bind.setter
    def settled_and_bind(self, value):
        self._settled_and_bind = value
    @property
    def user_bind_card_time(self):
        return self._user_bind_card_time

    @user_bind_card_time.setter
    def user_bind_card_time(self, value):
        self._user_bind_card_time = value
    @property
    def user_cert_time(self):
        return self._user_cert_time

    @user_cert_time.setter
    def user_cert_time(self, value):
        self._user_cert_time = value
    @property
    def user_prize_time(self):
        return self._user_prize_time

    @user_prize_time.setter
    def user_prize_time(self, value):
        self._user_prize_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.city_name:
            if hasattr(self.city_name, 'to_alipay_dict'):
                params['city_name'] = self.city_name.to_alipay_dict()
            else:
                params['city_name'] = self.city_name
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.invited_phone:
            if hasattr(self.invited_phone, 'to_alipay_dict'):
                params['invited_phone'] = self.invited_phone.to_alipay_dict()
            else:
                params['invited_phone'] = self.invited_phone
        if self.lbs_rate:
            if hasattr(self.lbs_rate, 'to_alipay_dict'):
                params['lbs_rate'] = self.lbs_rate.to_alipay_dict()
            else:
                params['lbs_rate'] = self.lbs_rate
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.province_name:
            if hasattr(self.province_name, 'to_alipay_dict'):
                params['province_name'] = self.province_name.to_alipay_dict()
            else:
                params['province_name'] = self.province_name
        if self.settled:
            if hasattr(self.settled, 'to_alipay_dict'):
                params['settled'] = self.settled.to_alipay_dict()
            else:
                params['settled'] = self.settled
        if self.settled_and_bind:
            if hasattr(self.settled_and_bind, 'to_alipay_dict'):
                params['settled_and_bind'] = self.settled_and_bind.to_alipay_dict()
            else:
                params['settled_and_bind'] = self.settled_and_bind
        if self.user_bind_card_time:
            if hasattr(self.user_bind_card_time, 'to_alipay_dict'):
                params['user_bind_card_time'] = self.user_bind_card_time.to_alipay_dict()
            else:
                params['user_bind_card_time'] = self.user_bind_card_time
        if self.user_cert_time:
            if hasattr(self.user_cert_time, 'to_alipay_dict'):
                params['user_cert_time'] = self.user_cert_time.to_alipay_dict()
            else:
                params['user_cert_time'] = self.user_cert_time
        if self.user_prize_time:
            if hasattr(self.user_prize_time, 'to_alipay_dict'):
                params['user_prize_time'] = self.user_prize_time.to_alipay_dict()
            else:
                params['user_prize_time'] = self.user_prize_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OfflineInviteNewerDetailInfo()
        if 'city_name' in d:
            o.city_name = d['city_name']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'invited_phone' in d:
            o.invited_phone = d['invited_phone']
        if 'lbs_rate' in d:
            o.lbs_rate = d['lbs_rate']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'pid' in d:
            o.pid = d['pid']
        if 'province_name' in d:
            o.province_name = d['province_name']
        if 'settled' in d:
            o.settled = d['settled']
        if 'settled_and_bind' in d:
            o.settled_and_bind = d['settled_and_bind']
        if 'user_bind_card_time' in d:
            o.user_bind_card_time = d['user_bind_card_time']
        if 'user_cert_time' in d:
            o.user_cert_time = d['user_cert_time']
        if 'user_prize_time' in d:
            o.user_prize_time = d['user_prize_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiAdvertCommissionChannelDeleteModel(object):

    def __init__(self):
        self._channel_ids = None

    @property
    def channel_ids(self):
        return self._channel_ids

    @channel_ids.setter
    def channel_ids(self, value):
        if isinstance(value, list):
            self._channel_ids = list()
            for i in value:
                self._channel_ids.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.channel_ids:
            if isinstance(self.channel_ids, list):
                for i in range(0, len(self.channel_ids)):
                    element = self.channel_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.channel_ids[i] = element.to_alipay_dict()
            if hasattr(self.channel_ids, 'to_alipay_dict'):
                params['channel_ids'] = self.channel_ids.to_alipay_dict()
            else:
                params['channel_ids'] = self.channel_ids
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiAdvertCommissionChannelDeleteModel()
        if 'channel_ids' in d:
            o.channel_ids = d['channel_ids']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEducateScenePhotoremoteApplyModel(object):

    def __init__(self):
        self._cert_no = None
        self._cert_type = None
        self._image_content = None
        self._out_photo_id = None
        self._parent_phone_number = None
        self._school_std_code = None
        self._student_name = None

    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def image_content(self):
        return self._image_content

    @image_content.setter
    def image_content(self, value):
        self._image_content = value
    @property
    def out_photo_id(self):
        return self._out_photo_id

    @out_photo_id.setter
    def out_photo_id(self, value):
        self._out_photo_id = value
    @property
    def parent_phone_number(self):
        return self._parent_phone_number

    @parent_phone_number.setter
    def parent_phone_number(self, value):
        self._parent_phone_number = value
    @property
    def school_std_code(self):
        return self._school_std_code

    @school_std_code.setter
    def school_std_code(self, value):
        self._school_std_code = value
    @property
    def student_name(self):
        return self._student_name

    @student_name.setter
    def student_name(self, value):
        self._student_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.image_content:
            if hasattr(self.image_content, 'to_alipay_dict'):
                params['image_content'] = self.image_content.to_alipay_dict()
            else:
                params['image_content'] = self.image_content
        if self.out_photo_id:
            if hasattr(self.out_photo_id, 'to_alipay_dict'):
                params['out_photo_id'] = self.out_photo_id.to_alipay_dict()
            else:
                params['out_photo_id'] = self.out_photo_id
        if self.parent_phone_number:
            if hasattr(self.parent_phone_number, 'to_alipay_dict'):
                params['parent_phone_number'] = self.parent_phone_number.to_alipay_dict()
            else:
                params['parent_phone_number'] = self.parent_phone_number
        if self.school_std_code:
            if hasattr(self.school_std_code, 'to_alipay_dict'):
                params['school_std_code'] = self.school_std_code.to_alipay_dict()
            else:
                params['school_std_code'] = self.school_std_code
        if self.student_name:
            if hasattr(self.student_name, 'to_alipay_dict'):
                params['student_name'] = self.student_name.to_alipay_dict()
            else:
                params['student_name'] = self.student_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateScenePhotoremoteApplyModel()
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'image_content' in d:
            o.image_content = d['image_content']
        if 'out_photo_id' in d:
            o.out_photo_id = d['out_photo_id']
        if 'parent_phone_number' in d:
            o.parent_phone_number = d['parent_phone_number']
        if 'school_std_code' in d:
            o.school_std_code = d['school_std_code']
        if 'student_name' in d:
            o.student_name = d['student_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class EcoAppInfo(object):

    def __init__(self):
        self._app_code = None
        self._app_name = None

    @property
    def app_code(self):
        return self._app_code

    @app_code.setter
    def app_code(self, value):
        self._app_code = value
    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_code:
            if hasattr(self.app_code, 'to_alipay_dict'):
                params['app_code'] = self.app_code.to_alipay_dict()
            else:
                params['app_code'] = self.app_code
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = EcoAppInfo()
        if 'app_code' in d:
            o.app_code = d['app_code']
        if 'app_name' in d:
            o.app_name = d['app_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.BaseOpenApiResponseHeaderDTO import BaseOpenApiResponseHeaderDTO
from alipay.aop.api.domain.TransactionDetailDTO import TransactionDetailDTO


class AlipayPayApplepayTransactionBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayPayApplepayTransactionBatchqueryResponse, self).__init__()
        self._last_updated_tag = None
        self._response_header = None
        self._transaction_details = None

    @property
    def last_updated_tag(self):
        return self._last_updated_tag

    @last_updated_tag.setter
    def last_updated_tag(self, value):
        self._last_updated_tag = value
    @property
    def response_header(self):
        return self._response_header

    @response_header.setter
    def response_header(self, value):
        if isinstance(value, BaseOpenApiResponseHeaderDTO):
            self._response_header = value
        else:
            self._response_header = BaseOpenApiResponseHeaderDTO.from_alipay_dict(value)
    @property
    def transaction_details(self):
        return self._transaction_details

    @transaction_details.setter
    def transaction_details(self, value):
        if isinstance(value, list):
            self._transaction_details = list()
            for i in value:
                if isinstance(i, TransactionDetailDTO):
                    self._transaction_details.append(i)
                else:
                    self._transaction_details.append(TransactionDetailDTO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayPayApplepayTransactionBatchqueryResponse, self).parse_response_content(response_content)
        if 'last_updated_tag' in response:
            self.last_updated_tag = response['last_updated_tag']
        if 'response_header' in response:
            self.response_header = response['response_header']
        if 'transaction_details' in response:
            self.transaction_details = response['transaction_details']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MallConsumeVoucher import MallConsumeVoucher
from alipay.aop.api.domain.MallGoodsDetail import MallGoodsDetail
from alipay.aop.api.domain.SceneOrder import SceneOrder
from alipay.aop.api.domain.MallUserVerify import MallUserVerify


class KoubeiMallScanpurchaseTraderesultQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMallScanpurchaseTraderesultQueryResponse, self).__init__()
        self._banner = None
        self._buyer_user_id = None
        self._consume_voucher = None
        self._goods_details = None
        self._out_trade_no = None
        self._scene_order = None
        self._seller_user_id = None
        self._trade_no = None
        self._user_verify = None

    @property
    def banner(self):
        return self._banner

    @banner.setter
    def banner(self, value):
        self._banner = value
    @property
    def buyer_user_id(self):
        return self._buyer_user_id

    @buyer_user_id.setter
    def buyer_user_id(self, value):
        self._buyer_user_id = value
    @property
    def consume_voucher(self):
        return self._consume_voucher

    @consume_voucher.setter
    def consume_voucher(self, value):
        if isinstance(value, MallConsumeVoucher):
            self._consume_voucher = value
        else:
            self._consume_voucher = MallConsumeVoucher.from_alipay_dict(value)
    @property
    def goods_details(self):
        return self._goods_details

    @goods_details.setter
    def goods_details(self, value):
        if isinstance(value, list):
            self._goods_details = list()
            for i in value:
                if isinstance(i, MallGoodsDetail):
                    self._goods_details.append(i)
                else:
                    self._goods_details.append(MallGoodsDetail.from_alipay_dict(i))
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def scene_order(self):
        return self._scene_order

    @scene_order.setter
    def scene_order(self, value):
        if isinstance(value, SceneOrder):
            self._scene_order = value
        else:
            self._scene_order = SceneOrder.from_alipay_dict(value)
    @property
    def seller_user_id(self):
        return self._seller_user_id

    @seller_user_id.setter
    def seller_user_id(self, value):
        self._seller_user_id = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def user_verify(self):
        return self._user_verify

    @user_verify.setter
    def user_verify(self, value):
        if isinstance(value, MallUserVerify):
            self._user_verify = value
        else:
            self._user_verify = MallUserVerify.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(KoubeiMallScanpurchaseTraderesultQueryResponse, self).parse_response_content(response_content)
        if 'banner' in response:
            self.banner = response['banner']
        if 'buyer_user_id' in response:
            self.buyer_user_id = response['buyer_user_id']
        if 'consume_voucher' in response:
            self.consume_voucher = response['consume_voucher']
        if 'goods_details' in response:
            self.goods_details = response['goods_details']
        if 'out_trade_no' in response:
            self.out_trade_no = response['out_trade_no']
        if 'scene_order' in response:
            self.scene_order = response['scene_order']
        if 'seller_user_id' in response:
            self.seller_user_id = response['seller_user_id']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']
        if 'user_verify' in response:
            self.user_verify = response['user_verify']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.BPOpenApiInstancePreviewStep import BPOpenApiInstancePreviewStep


class AlipayBossBaseProcessInstancePreviewResponse(AlipayResponse):

    def __init__(self):
        super(AlipayBossBaseProcessInstancePreviewResponse, self).__init__()
        self._preview_step = None

    @property
    def preview_step(self):
        return self._preview_step

    @preview_step.setter
    def preview_step(self, value):
        if isinstance(value, BPOpenApiInstancePreviewStep):
            self._preview_step = value
        else:
            self._preview_step = BPOpenApiInstancePreviewStep.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayBossBaseProcessInstancePreviewResponse, self).parse_response_content(response_content)
        if 'preview_step' in response:
            self.preview_step = response['preview_step']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoRenthouseBookInfo(object):

    def __init__(self):
        self._book_amount = None
        self._book_sale_amount = None
        self._latest_signing_date = None
        self._lease_begin_date = None
        self._lease_end_date = None
        self._remark = None

    @property
    def book_amount(self):
        return self._book_amount

    @book_amount.setter
    def book_amount(self, value):
        self._book_amount = value
    @property
    def book_sale_amount(self):
        return self._book_sale_amount

    @book_sale_amount.setter
    def book_sale_amount(self, value):
        self._book_sale_amount = value
    @property
    def latest_signing_date(self):
        return self._latest_signing_date

    @latest_signing_date.setter
    def latest_signing_date(self, value):
        self._latest_signing_date = value
    @property
    def lease_begin_date(self):
        return self._lease_begin_date

    @lease_begin_date.setter
    def lease_begin_date(self, value):
        self._lease_begin_date = value
    @property
    def lease_end_date(self):
        return self._lease_end_date

    @lease_end_date.setter
    def lease_end_date(self, value):
        self._lease_end_date = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value


    def to_alipay_dict(self):
        params = dict()
        if self.book_amount:
            if hasattr(self.book_amount, 'to_alipay_dict'):
                params['book_amount'] = self.book_amount.to_alipay_dict()
            else:
                params['book_amount'] = self.book_amount
        if self.book_sale_amount:
            if hasattr(self.book_sale_amount, 'to_alipay_dict'):
                params['book_sale_amount'] = self.book_sale_amount.to_alipay_dict()
            else:
                params['book_sale_amount'] = self.book_sale_amount
        if self.latest_signing_date:
            if hasattr(self.latest_signing_date, 'to_alipay_dict'):
                params['latest_signing_date'] = self.latest_signing_date.to_alipay_dict()
            else:
                params['latest_signing_date'] = self.latest_signing_date
        if self.lease_begin_date:
            if hasattr(self.lease_begin_date, 'to_alipay_dict'):
                params['lease_begin_date'] = self.lease_begin_date.to_alipay_dict()
            else:
                params['lease_begin_date'] = self.lease_begin_date
        if self.lease_end_date:
            if hasattr(self.lease_end_date, 'to_alipay_dict'):
                params['lease_end_date'] = self.lease_end_date.to_alipay_dict()
            else:
                params['lease_end_date'] = self.lease_end_date
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoRenthouseBookInfo()
        if 'book_amount' in d:
            o.book_amount = d['book_amount']
        if 'book_sale_amount' in d:
            o.book_sale_amount = d['book_sale_amount']
        if 'latest_signing_date' in d:
            o.latest_signing_date = d['latest_signing_date']
        if 'lease_begin_date' in d:
            o.lease_begin_date = d['lease_begin_date']
        if 'lease_end_date' in d:
            o.lease_end_date = d['lease_end_date']
        if 'remark' in d:
            o.remark = d['remark']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceLogisticsUserOrderQueryModel(object):

    def __init__(self):
        self._biz_type = None
        self._ext_param = None
        self._merchant_code = None
        self._target_id = None
        self._target_id_type = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def ext_param(self):
        return self._ext_param

    @ext_param.setter
    def ext_param(self, value):
        self._ext_param = value
    @property
    def merchant_code(self):
        return self._merchant_code

    @merchant_code.setter
    def merchant_code(self, value):
        self._merchant_code = value
    @property
    def target_id(self):
        return self._target_id

    @target_id.setter
    def target_id(self, value):
        self._target_id = value
    @property
    def target_id_type(self):
        return self._target_id_type

    @target_id_type.setter
    def target_id_type(self, value):
        self._target_id_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.ext_param:
            if hasattr(self.ext_param, 'to_alipay_dict'):
                params['ext_param'] = self.ext_param.to_alipay_dict()
            else:
                params['ext_param'] = self.ext_param
        if self.merchant_code:
            if hasattr(self.merchant_code, 'to_alipay_dict'):
                params['merchant_code'] = self.merchant_code.to_alipay_dict()
            else:
                params['merchant_code'] = self.merchant_code
        if self.target_id:
            if hasattr(self.target_id, 'to_alipay_dict'):
                params['target_id'] = self.target_id.to_alipay_dict()
            else:
                params['target_id'] = self.target_id
        if self.target_id_type:
            if hasattr(self.target_id_type, 'to_alipay_dict'):
                params['target_id_type'] = self.target_id_type.to_alipay_dict()
            else:
                params['target_id_type'] = self.target_id_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceLogisticsUserOrderQueryModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'ext_param' in d:
            o.ext_param = d['ext_param']
        if 'merchant_code' in d:
            o.merchant_code = d['merchant_code']
        if 'target_id' in d:
            o.target_id = d['target_id']
        if 'target_id_type' in d:
            o.target_id_type = d['target_id_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingCardActivateurlApplyModel(object):

    def __init__(self):
        self._callback = None
        self._follow_app_id = None
        self._out_string = None
        self._template_id = None

    @property
    def callback(self):
        return self._callback

    @callback.setter
    def callback(self, value):
        self._callback = value
    @property
    def follow_app_id(self):
        return self._follow_app_id

    @follow_app_id.setter
    def follow_app_id(self, value):
        self._follow_app_id = value
    @property
    def out_string(self):
        return self._out_string

    @out_string.setter
    def out_string(self, value):
        self._out_string = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.callback:
            if hasattr(self.callback, 'to_alipay_dict'):
                params['callback'] = self.callback.to_alipay_dict()
            else:
                params['callback'] = self.callback
        if self.follow_app_id:
            if hasattr(self.follow_app_id, 'to_alipay_dict'):
                params['follow_app_id'] = self.follow_app_id.to_alipay_dict()
            else:
                params['follow_app_id'] = self.follow_app_id
        if self.out_string:
            if hasattr(self.out_string, 'to_alipay_dict'):
                params['out_string'] = self.out_string.to_alipay_dict()
            else:
                params['out_string'] = self.out_string
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCardActivateurlApplyModel()
        if 'callback' in d:
            o.callback = d['callback']
        if 'follow_app_id' in d:
            o.follow_app_id = d['follow_app_id']
        if 'out_string' in d:
            o.out_string = d['out_string']
        if 'template_id' in d:
            o.template_id = d['template_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserAddressQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserAddressQueryResponse, self).__init__()
        self._address = None
        self._address_code = None
        self._area = None
        self._city = None
        self._coordinate = None
        self._default_user_address = None
        self._fullname = None
        self._mobile = None
        self._prov = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def address_code(self):
        return self._address_code

    @address_code.setter
    def address_code(self, value):
        self._address_code = value
    @property
    def area(self):
        return self._area

    @area.setter
    def area(self, value):
        self._area = value
    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def coordinate(self):
        return self._coordinate

    @coordinate.setter
    def coordinate(self, value):
        self._coordinate = value
    @property
    def default_user_address(self):
        return self._default_user_address

    @default_user_address.setter
    def default_user_address(self, value):
        self._default_user_address = value
    @property
    def fullname(self):
        return self._fullname

    @fullname.setter
    def fullname(self, value):
        self._fullname = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def prov(self):
        return self._prov

    @prov.setter
    def prov(self, value):
        self._prov = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserAddressQueryResponse, self).parse_response_content(response_content)
        if 'address' in response:
            self.address = response['address']
        if 'address_code' in response:
            self.address_code = response['address_code']
        if 'area' in response:
            self.area = response['area']
        if 'city' in response:
            self.city = response['city']
        if 'coordinate' in response:
            self.coordinate = response['coordinate']
        if 'default_user_address' in response:
            self.default_user_address = response['default_user_address']
        if 'fullname' in response:
            self.fullname = response['fullname']
        if 'mobile' in response:
            self.mobile = response['mobile']
        if 'prov' in response:
            self.prov = response['prov']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.DataFile import DataFile


class ZhimaCreditEpCreditlinkCollectQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditEpCreditlinkCollectQueryResponse, self).__init__()
        self._data_status = None
        self._data_type = None
        self._encrypt_model = None
        self._file_list = None
        self._file_num = None
        self._files = None
        self._merchant_request_id = None
        self._secret = None

    @property
    def data_status(self):
        return self._data_status

    @data_status.setter
    def data_status(self, value):
        self._data_status = value
    @property
    def data_type(self):
        return self._data_type

    @data_type.setter
    def data_type(self, value):
        self._data_type = value
    @property
    def encrypt_model(self):
        return self._encrypt_model

    @encrypt_model.setter
    def encrypt_model(self, value):
        self._encrypt_model = value
    @property
    def file_list(self):
        return self._file_list

    @file_list.setter
    def file_list(self, value):
        if isinstance(value, list):
            self._file_list = list()
            for i in value:
                self._file_list.append(i)
    @property
    def file_num(self):
        return self._file_num

    @file_num.setter
    def file_num(self, value):
        self._file_num = value
    @property
    def files(self):
        return self._files

    @files.setter
    def files(self, value):
        if isinstance(value, list):
            self._files = list()
            for i in value:
                if isinstance(i, DataFile):
                    self._files.append(i)
                else:
                    self._files.append(DataFile.from_alipay_dict(i))
    @property
    def merchant_request_id(self):
        return self._merchant_request_id

    @merchant_request_id.setter
    def merchant_request_id(self, value):
        self._merchant_request_id = value
    @property
    def secret(self):
        return self._secret

    @secret.setter
    def secret(self, value):
        self._secret = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditEpCreditlinkCollectQueryResponse, self).parse_response_content(response_content)
        if 'data_status' in response:
            self.data_status = response['data_status']
        if 'data_type' in response:
            self.data_type = response['data_type']
        if 'encrypt_model' in response:
            self.encrypt_model = response['encrypt_model']
        if 'file_list' in response:
            self.file_list = response['file_list']
        if 'file_num' in response:
            self.file_num = response['file_num']
        if 'files' in response:
            self.files = response['files']
        if 'merchant_request_id' in response:
            self.merchant_request_id = response['merchant_request_id']
        if 'secret' in response:
            self.secret = response['secret']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AntMerchantExpandMccQueryModel(object):

    def __init__(self):
        self._mcc_code_list = None

    @property
    def mcc_code_list(self):
        return self._mcc_code_list

    @mcc_code_list.setter
    def mcc_code_list(self, value):
        self._mcc_code_list = value


    def to_alipay_dict(self):
        params = dict()
        if self.mcc_code_list:
            if hasattr(self.mcc_code_list, 'to_alipay_dict'):
                params['mcc_code_list'] = self.mcc_code_list.to_alipay_dict()
            else:
                params['mcc_code_list'] = self.mcc_code_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandMccQueryModel()
        if 'mcc_code_list' in d:
            o.mcc_code_list = d['mcc_code_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BudgetInfo import BudgetInfo
from alipay.aop.api.domain.ConstraintInfo import ConstraintInfo
from alipay.aop.api.domain.PromoTool import PromoTool
from alipay.aop.api.domain.PublishChannel import PublishChannel
from alipay.aop.api.domain.RecruitTool import RecruitTool


class KoubeiMarketingCampaignActivityModifyModel(object):

    def __init__(self):
        self._auto_delay_flag = None
        self._budget_info = None
        self._camp_id = None
        self._constraint_info = None
        self._desc = None
        self._end_time = None
        self._ext_info = None
        self._name = None
        self._operator_id = None
        self._operator_type = None
        self._out_biz_no = None
        self._promo_tools = None
        self._publish_channels = None
        self._recruit_tool = None
        self._start_time = None
        self._type = None

    @property
    def auto_delay_flag(self):
        return self._auto_delay_flag

    @auto_delay_flag.setter
    def auto_delay_flag(self, value):
        self._auto_delay_flag = value
    @property
    def budget_info(self):
        return self._budget_info

    @budget_info.setter
    def budget_info(self, value):
        if isinstance(value, BudgetInfo):
            self._budget_info = value
        else:
            self._budget_info = BudgetInfo.from_alipay_dict(value)
    @property
    def camp_id(self):
        return self._camp_id

    @camp_id.setter
    def camp_id(self, value):
        self._camp_id = value
    @property
    def constraint_info(self):
        return self._constraint_info

    @constraint_info.setter
    def constraint_info(self, value):
        if isinstance(value, ConstraintInfo):
            self._constraint_info = value
        else:
            self._constraint_info = ConstraintInfo.from_alipay_dict(value)
    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def operator_id(self):
        return self._operator_id

    @operator_id.setter
    def operator_id(self, value):
        self._operator_id = value
    @property
    def operator_type(self):
        return self._operator_type

    @operator_type.setter
    def operator_type(self, value):
        self._operator_type = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def promo_tools(self):
        return self._promo_tools

    @promo_tools.setter
    def promo_tools(self, value):
        if isinstance(value, list):
            self._promo_tools = list()
            for i in value:
                if isinstance(i, PromoTool):
                    self._promo_tools.append(i)
                else:
                    self._promo_tools.append(PromoTool.from_alipay_dict(i))
    @property
    def publish_channels(self):
        return self._publish_channels

    @publish_channels.setter
    def publish_channels(self, value):
        if isinstance(value, list):
            self._publish_channels = list()
            for i in value:
                if isinstance(i, PublishChannel):
                    self._publish_channels.append(i)
                else:
                    self._publish_channels.append(PublishChannel.from_alipay_dict(i))
    @property
    def recruit_tool(self):
        return self._recruit_tool

    @recruit_tool.setter
    def recruit_tool(self, value):
        if isinstance(value, RecruitTool):
            self._recruit_tool = value
        else:
            self._recruit_tool = RecruitTool.from_alipay_dict(value)
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.auto_delay_flag:
            if hasattr(self.auto_delay_flag, 'to_alipay_dict'):
                params['auto_delay_flag'] = self.auto_delay_flag.to_alipay_dict()
            else:
                params['auto_delay_flag'] = self.auto_delay_flag
        if self.budget_info:
            if hasattr(self.budget_info, 'to_alipay_dict'):
                params['budget_info'] = self.budget_info.to_alipay_dict()
            else:
                params['budget_info'] = self.budget_info
        if self.camp_id:
            if hasattr(self.camp_id, 'to_alipay_dict'):
                params['camp_id'] = self.camp_id.to_alipay_dict()
            else:
                params['camp_id'] = self.camp_id
        if self.constraint_info:
            if hasattr(self.constraint_info, 'to_alipay_dict'):
                params['constraint_info'] = self.constraint_info.to_alipay_dict()
            else:
                params['constraint_info'] = self.constraint_info
        if self.desc:
            if hasattr(self.desc, 'to_alipay_dict'):
                params['desc'] = self.desc.to_alipay_dict()
            else:
                params['desc'] = self.desc
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.operator_id:
            if hasattr(self.operator_id, 'to_alipay_dict'):
                params['operator_id'] = self.operator_id.to_alipay_dict()
            else:
                params['operator_id'] = self.operator_id
        if self.operator_type:
            if hasattr(self.operator_type, 'to_alipay_dict'):
                params['operator_type'] = self.operator_type.to_alipay_dict()
            else:
                params['operator_type'] = self.operator_type
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.promo_tools:
            if isinstance(self.promo_tools, list):
                for i in range(0, len(self.promo_tools)):
                    element = self.promo_tools[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.promo_tools[i] = element.to_alipay_dict()
            if hasattr(self.promo_tools, 'to_alipay_dict'):
                params['promo_tools'] = self.promo_tools.to_alipay_dict()
            else:
                params['promo_tools'] = self.promo_tools
        if self.publish_channels:
            if isinstance(self.publish_channels, list):
                for i in range(0, len(self.publish_channels)):
                    element = self.publish_channels[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.publish_channels[i] = element.to_alipay_dict()
            if hasattr(self.publish_channels, 'to_alipay_dict'):
                params['publish_channels'] = self.publish_channels.to_alipay_dict()
            else:
                params['publish_channels'] = self.publish_channels
        if self.recruit_tool:
            if hasattr(self.recruit_tool, 'to_alipay_dict'):
                params['recruit_tool'] = self.recruit_tool.to_alipay_dict()
            else:
                params['recruit_tool'] = self.recruit_tool
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMarketingCampaignActivityModifyModel()
        if 'auto_delay_flag' in d:
            o.auto_delay_flag = d['auto_delay_flag']
        if 'budget_info' in d:
            o.budget_info = d['budget_info']
        if 'camp_id' in d:
            o.camp_id = d['camp_id']
        if 'constraint_info' in d:
            o.constraint_info = d['constraint_info']
        if 'desc' in d:
            o.desc = d['desc']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'name' in d:
            o.name = d['name']
        if 'operator_id' in d:
            o.operator_id = d['operator_id']
        if 'operator_type' in d:
            o.operator_type = d['operator_type']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'promo_tools' in d:
            o.promo_tools = d['promo_tools']
        if 'publish_channels' in d:
            o.publish_channels = d['publish_channels']
        if 'recruit_tool' in d:
            o.recruit_tool = d['recruit_tool']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ShopOrderModifyResult(object):

    def __init__(self):
        self._ext_infos = None
        self._result_code = None
        self._shop_id = None
        self._store_id = None

    @property
    def ext_infos(self):
        return self._ext_infos

    @ext_infos.setter
    def ext_infos(self, value):
        self._ext_infos = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def store_id(self):
        return self._store_id

    @store_id.setter
    def store_id(self, value):
        self._store_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.ext_infos:
            if hasattr(self.ext_infos, 'to_alipay_dict'):
                params['ext_infos'] = self.ext_infos.to_alipay_dict()
            else:
                params['ext_infos'] = self.ext_infos
        if self.result_code:
            if hasattr(self.result_code, 'to_alipay_dict'):
                params['result_code'] = self.result_code.to_alipay_dict()
            else:
                params['result_code'] = self.result_code
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.store_id:
            if hasattr(self.store_id, 'to_alipay_dict'):
                params['store_id'] = self.store_id.to_alipay_dict()
            else:
                params['store_id'] = self.store_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ShopOrderModifyResult()
        if 'ext_infos' in d:
            o.ext_infos = d['ext_infos']
        if 'result_code' in d:
            o.result_code = d['result_code']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'store_id' in d:
            o.store_id = d['store_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DeviceSyncPayload import DeviceSyncPayload


class AlipayMsaasItapDeviceSyncModel(object):

    def __init__(self):
        self._payload = None
        self._request_id = None
        self._user_id = None

    @property
    def payload(self):
        return self._payload

    @payload.setter
    def payload(self, value):
        if isinstance(value, list):
            self._payload = list()
            for i in value:
                if isinstance(i, DeviceSyncPayload):
                    self._payload.append(i)
                else:
                    self._payload.append(DeviceSyncPayload.from_alipay_dict(i))
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.payload:
            if isinstance(self.payload, list):
                for i in range(0, len(self.payload)):
                    element = self.payload[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.payload[i] = element.to_alipay_dict()
            if hasattr(self.payload, 'to_alipay_dict'):
                params['payload'] = self.payload.to_alipay_dict()
            else:
                params['payload'] = self.payload
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMsaasItapDeviceSyncModel()
        if 'payload' in d:
            o.payload = d['payload']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundJointaccountTradePayModel(object):

    def __init__(self):
        self._account_id = None
        self._biz_scene = None
        self._ext_info = None
        self._hide_menu = None
        self._product_code = None
        self._type = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def hide_menu(self):
        return self._hide_menu

    @hide_menu.setter
    def hide_menu(self, value):
        self._hide_menu = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.hide_menu:
            if hasattr(self.hide_menu, 'to_alipay_dict'):
                params['hide_menu'] = self.hide_menu.to_alipay_dict()
            else:
                params['hide_menu'] = self.hide_menu
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundJointaccountTradePayModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'hide_menu' in d:
            o.hide_menu = d['hide_menu']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceOperationTerminalPowerbankorderInitializeModel(object):

    def __init__(self):
        self._auth_id = None
        self._out_trade_id = None
        self._sn = None
        self._user_id = None

    @property
    def auth_id(self):
        return self._auth_id

    @auth_id.setter
    def auth_id(self, value):
        self._auth_id = value
    @property
    def out_trade_id(self):
        return self._out_trade_id

    @out_trade_id.setter
    def out_trade_id(self, value):
        self._out_trade_id = value
    @property
    def sn(self):
        return self._sn

    @sn.setter
    def sn(self, value):
        self._sn = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_id:
            if hasattr(self.auth_id, 'to_alipay_dict'):
                params['auth_id'] = self.auth_id.to_alipay_dict()
            else:
                params['auth_id'] = self.auth_id
        if self.out_trade_id:
            if hasattr(self.out_trade_id, 'to_alipay_dict'):
                params['out_trade_id'] = self.out_trade_id.to_alipay_dict()
            else:
                params['out_trade_id'] = self.out_trade_id
        if self.sn:
            if hasattr(self.sn, 'to_alipay_dict'):
                params['sn'] = self.sn.to_alipay_dict()
            else:
                params['sn'] = self.sn
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceOperationTerminalPowerbankorderInitializeModel()
        if 'auth_id' in d:
            o.auth_id = d['auth_id']
        if 'out_trade_id' in d:
            o.out_trade_id = d['out_trade_id']
        if 'sn' in d:
            o.sn = d['sn']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ForbbidenTime import ForbbidenTime
from alipay.aop.api.domain.UseTime import UseTime


class VoucherDetailInfo(object):

    def __init__(self):
        self._asset_id = None
        self._effect_time = None
        self._ext_info = None
        self._forbbiden_time = None
        self._invalid_time = None
        self._sku_codes = None
        self._time_rules = None
        self._use_condition = None
        self._voucher_desc = None
        self._voucher_type = None

    @property
    def asset_id(self):
        return self._asset_id

    @asset_id.setter
    def asset_id(self, value):
        self._asset_id = value
    @property
    def effect_time(self):
        return self._effect_time

    @effect_time.setter
    def effect_time(self, value):
        self._effect_time = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def forbbiden_time(self):
        return self._forbbiden_time

    @forbbiden_time.setter
    def forbbiden_time(self, value):
        if isinstance(value, ForbbidenTime):
            self._forbbiden_time = value
        else:
            self._forbbiden_time = ForbbidenTime.from_alipay_dict(value)
    @property
    def invalid_time(self):
        return self._invalid_time

    @invalid_time.setter
    def invalid_time(self, value):
        self._invalid_time = value
    @property
    def sku_codes(self):
        return self._sku_codes

    @sku_codes.setter
    def sku_codes(self, value):
        self._sku_codes = value
    @property
    def time_rules(self):
        return self._time_rules

    @time_rules.setter
    def time_rules(self, value):
        if isinstance(value, list):
            self._time_rules = list()
            for i in value:
                if isinstance(i, UseTime):
                    self._time_rules.append(i)
                else:
                    self._time_rules.append(UseTime.from_alipay_dict(i))
    @property
    def use_condition(self):
        return self._use_condition

    @use_condition.setter
    def use_condition(self, value):
        self._use_condition = value
    @property
    def voucher_desc(self):
        return self._voucher_desc

    @voucher_desc.setter
    def voucher_desc(self, value):
        self._voucher_desc = value
    @property
    def voucher_type(self):
        return self._voucher_type

    @voucher_type.setter
    def voucher_type(self, value):
        self._voucher_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.asset_id:
            if hasattr(self.asset_id, 'to_alipay_dict'):
                params['asset_id'] = self.asset_id.to_alipay_dict()
            else:
                params['asset_id'] = self.asset_id
        if self.effect_time:
            if hasattr(self.effect_time, 'to_alipay_dict'):
                params['effect_time'] = self.effect_time.to_alipay_dict()
            else:
                params['effect_time'] = self.effect_time
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.forbbiden_time:
            if hasattr(self.forbbiden_time, 'to_alipay_dict'):
                params['forbbiden_time'] = self.forbbiden_time.to_alipay_dict()
            else:
                params['forbbiden_time'] = self.forbbiden_time
        if self.invalid_time:
            if hasattr(self.invalid_time, 'to_alipay_dict'):
                params['invalid_time'] = self.invalid_time.to_alipay_dict()
            else:
                params['invalid_time'] = self.invalid_time
        if self.sku_codes:
            if hasattr(self.sku_codes, 'to_alipay_dict'):
                params['sku_codes'] = self.sku_codes.to_alipay_dict()
            else:
                params['sku_codes'] = self.sku_codes
        if self.time_rules:
            if isinstance(self.time_rules, list):
                for i in range(0, len(self.time_rules)):
                    element = self.time_rules[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.time_rules[i] = element.to_alipay_dict()
            if hasattr(self.time_rules, 'to_alipay_dict'):
                params['time_rules'] = self.time_rules.to_alipay_dict()
            else:
                params['time_rules'] = self.time_rules
        if self.use_condition:
            if hasattr(self.use_condition, 'to_alipay_dict'):
                params['use_condition'] = self.use_condition.to_alipay_dict()
            else:
                params['use_condition'] = self.use_condition
        if self.voucher_desc:
            if hasattr(self.voucher_desc, 'to_alipay_dict'):
                params['voucher_desc'] = self.voucher_desc.to_alipay_dict()
            else:
                params['voucher_desc'] = self.voucher_desc
        if self.voucher_type:
            if hasattr(self.voucher_type, 'to_alipay_dict'):
                params['voucher_type'] = self.voucher_type.to_alipay_dict()
            else:
                params['voucher_type'] = self.voucher_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherDetailInfo()
        if 'asset_id' in d:
            o.asset_id = d['asset_id']
        if 'effect_time' in d:
            o.effect_time = d['effect_time']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'forbbiden_time' in d:
            o.forbbiden_time = d['forbbiden_time']
        if 'invalid_time' in d:
            o.invalid_time = d['invalid_time']
        if 'sku_codes' in d:
            o.sku_codes = d['sku_codes']
        if 'time_rules' in d:
            o.time_rules = d['time_rules']
        if 'use_condition' in d:
            o.use_condition = d['use_condition']
        if 'voucher_desc' in d:
            o.voucher_desc = d['voucher_desc']
        if 'voucher_type' in d:
            o.voucher_type = d['voucher_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BusinessItem import BusinessItem


class AlipayEcoMycarParkingParkinglotinfoUpdateModel(object):

    def __init__(self):
        self._agent_id = None
        self._business_isv = None
        self._city_id = None
        self._contact_alipay = None
        self._contact_email = None
        self._contact_mobile = None
        self._contact_name = None
        self._contact_tel = None
        self._contact_weixin = None
        self._equipment_name = None
        self._is_support_invoice = None
        self._isv_mobile = None
        self._latitude = None
        self._longitude = None
        self._mchnt_id = None
        self._original_isv_appid = None
        self._original_isv_mobile = None
        self._original_isv_name = None
        self._original_isv_pid = None
        self._out_parking_id = None
        self._parking_address = None
        self._parking_end_time = None
        self._parking_fee_description = None
        self._parking_fee_description_img = None
        self._parking_id = None
        self._parking_lot_type = None
        self._parking_mobile = None
        self._parking_name = None
        self._parking_number = None
        self._parking_poiid = None
        self._parking_start_time = None
        self._parking_type = None
        self._pay_type = None
        self._payment_mode = None
        self._shopingmall_id = None
        self._sum_space = None
        self._support_after_pay = None
        self._time_out = None

    @property
    def agent_id(self):
        return self._agent_id

    @agent_id.setter
    def agent_id(self, value):
        self._agent_id = value
    @property
    def business_isv(self):
        return self._business_isv

    @business_isv.setter
    def business_isv(self, value):
        if isinstance(value, list):
            self._business_isv = list()
            for i in value:
                if isinstance(i, BusinessItem):
                    self._business_isv.append(i)
                else:
                    self._business_isv.append(BusinessItem.from_alipay_dict(i))
    @property
    def city_id(self):
        return self._city_id

    @city_id.setter
    def city_id(self, value):
        self._city_id = value
    @property
    def contact_alipay(self):
        return self._contact_alipay

    @contact_alipay.setter
    def contact_alipay(self, value):
        self._contact_alipay = value
    @property
    def contact_email(self):
        return self._contact_email

    @contact_email.setter
    def contact_email(self, value):
        self._contact_email = value
    @property
    def contact_mobile(self):
        return self._contact_mobile

    @contact_mobile.setter
    def contact_mobile(self, value):
        self._contact_mobile = value
    @property
    def contact_name(self):
        return self._contact_name

    @contact_name.setter
    def contact_name(self, value):
        self._contact_name = value
    @property
    def contact_tel(self):
        return self._contact_tel

    @contact_tel.setter
    def contact_tel(self, value):
        self._contact_tel = value
    @property
    def contact_weixin(self):
        return self._contact_weixin

    @contact_weixin.setter
    def contact_weixin(self, value):
        self._contact_weixin = value
    @property
    def equipment_name(self):
        return self._equipment_name

    @equipment_name.setter
    def equipment_name(self, value):
        self._equipment_name = value
    @property
    def is_support_invoice(self):
        return self._is_support_invoice

    @is_support_invoice.setter
    def is_support_invoice(self, value):
        self._is_support_invoice = value
    @property
    def isv_mobile(self):
        return self._isv_mobile

    @isv_mobile.setter
    def isv_mobile(self, value):
        self._isv_mobile = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def mchnt_id(self):
        return self._mchnt_id

    @mchnt_id.setter
    def mchnt_id(self, value):
        self._mchnt_id = value
    @property
    def original_isv_appid(self):
        return self._original_isv_appid

    @original_isv_appid.setter
    def original_isv_appid(self, value):
        self._original_isv_appid = value
    @property
    def original_isv_mobile(self):
        return self._original_isv_mobile

    @original_isv_mobile.setter
    def original_isv_mobile(self, value):
        self._original_isv_mobile = value
    @property
    def original_isv_name(self):
        return self._original_isv_name

    @original_isv_name.setter
    def original_isv_name(self, value):
        self._original_isv_name = value
    @property
    def original_isv_pid(self):
        return self._original_isv_pid

    @original_isv_pid.setter
    def original_isv_pid(self, value):
        self._original_isv_pid = value
    @property
    def out_parking_id(self):
        return self._out_parking_id

    @out_parking_id.setter
    def out_parking_id(self, value):
        self._out_parking_id = value
    @property
    def parking_address(self):
        return self._parking_address

    @parking_address.setter
    def parking_address(self, value):
        self._parking_address = value
    @property
    def parking_end_time(self):
        return self._parking_end_time

    @parking_end_time.setter
    def parking_end_time(self, value):
        self._parking_end_time = value
    @property
    def parking_fee_description(self):
        return self._parking_fee_description

    @parking_fee_description.setter
    def parking_fee_description(self, value):
        self._parking_fee_description = value
    @property
    def parking_fee_description_img(self):
        return self._parking_fee_description_img

    @parking_fee_description_img.setter
    def parking_fee_description_img(self, value):
        self._parking_fee_description_img = value
    @property
    def parking_id(self):
        return self._parking_id

    @parking_id.setter
    def parking_id(self, value):
        self._parking_id = value
    @property
    def parking_lot_type(self):
        return self._parking_lot_type

    @parking_lot_type.setter
    def parking_lot_type(self, value):
        self._parking_lot_type = value
    @property
    def parking_mobile(self):
        return self._parking_mobile

    @parking_mobile.setter
    def parking_mobile(self, value):
        self._parking_mobile = value
    @property
    def parking_name(self):
        return self._parking_name

    @parking_name.setter
    def parking_name(self, value):
        self._parking_name = value
    @property
    def parking_number(self):
        return self._parking_number

    @parking_number.setter
    def parking_number(self, value):
        self._parking_number = value
    @property
    def parking_poiid(self):
        return self._parking_poiid

    @parking_poiid.setter
    def parking_poiid(self, value):
        self._parking_poiid = value
    @property
    def parking_start_time(self):
        return self._parking_start_time

    @parking_start_time.setter
    def parking_start_time(self, value):
        self._parking_start_time = value
    @property
    def parking_type(self):
        return self._parking_type

    @parking_type.setter
    def parking_type(self, value):
        self._parking_type = value
    @property
    def pay_type(self):
        return self._pay_type

    @pay_type.setter
    def pay_type(self, value):
        self._pay_type = value
    @property
    def payment_mode(self):
        return self._payment_mode

    @payment_mode.setter
    def payment_mode(self, value):
        self._payment_mode = value
    @property
    def shopingmall_id(self):
        return self._shopingmall_id

    @shopingmall_id.setter
    def shopingmall_id(self, value):
        self._shopingmall_id = value
    @property
    def sum_space(self):
        return self._sum_space

    @sum_space.setter
    def sum_space(self, value):
        self._sum_space = value
    @property
    def support_after_pay(self):
        return self._support_after_pay

    @support_after_pay.setter
    def support_after_pay(self, value):
        self._support_after_pay = value
    @property
    def time_out(self):
        return self._time_out

    @time_out.setter
    def time_out(self, value):
        self._time_out = value


    def to_alipay_dict(self):
        params = dict()
        if self.agent_id:
            if hasattr(self.agent_id, 'to_alipay_dict'):
                params['agent_id'] = self.agent_id.to_alipay_dict()
            else:
                params['agent_id'] = self.agent_id
        if self.business_isv:
            if isinstance(self.business_isv, list):
                for i in range(0, len(self.business_isv)):
                    element = self.business_isv[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.business_isv[i] = element.to_alipay_dict()
            if hasattr(self.business_isv, 'to_alipay_dict'):
                params['business_isv'] = self.business_isv.to_alipay_dict()
            else:
                params['business_isv'] = self.business_isv
        if self.city_id:
            if hasattr(self.city_id, 'to_alipay_dict'):
                params['city_id'] = self.city_id.to_alipay_dict()
            else:
                params['city_id'] = self.city_id
        if self.contact_alipay:
            if hasattr(self.contact_alipay, 'to_alipay_dict'):
                params['contact_alipay'] = self.contact_alipay.to_alipay_dict()
            else:
                params['contact_alipay'] = self.contact_alipay
        if self.contact_email:
            if hasattr(self.contact_email, 'to_alipay_dict'):
                params['contact_email'] = self.contact_email.to_alipay_dict()
            else:
                params['contact_email'] = self.contact_email
        if self.contact_mobile:
            if hasattr(self.contact_mobile, 'to_alipay_dict'):
                params['contact_mobile'] = self.contact_mobile.to_alipay_dict()
            else:
                params['contact_mobile'] = self.contact_mobile
        if self.contact_name:
            if hasattr(self.contact_name, 'to_alipay_dict'):
                params['contact_name'] = self.contact_name.to_alipay_dict()
            else:
                params['contact_name'] = self.contact_name
        if self.contact_tel:
            if hasattr(self.contact_tel, 'to_alipay_dict'):
                params['contact_tel'] = self.contact_tel.to_alipay_dict()
            else:
                params['contact_tel'] = self.contact_tel
        if self.contact_weixin:
            if hasattr(self.contact_weixin, 'to_alipay_dict'):
                params['contact_weixin'] = self.contact_weixin.to_alipay_dict()
            else:
                params['contact_weixin'] = self.contact_weixin
        if self.equipment_name:
            if hasattr(self.equipment_name, 'to_alipay_dict'):
                params['equipment_name'] = self.equipment_name.to_alipay_dict()
            else:
                params['equipment_name'] = self.equipment_name
        if self.is_support_invoice:
            if hasattr(self.is_support_invoice, 'to_alipay_dict'):
                params['is_support_invoice'] = self.is_support_invoice.to_alipay_dict()
            else:
                params['is_support_invoice'] = self.is_support_invoice
        if self.isv_mobile:
            if hasattr(self.isv_mobile, 'to_alipay_dict'):
                params['isv_mobile'] = self.isv_mobile.to_alipay_dict()
            else:
                params['isv_mobile'] = self.isv_mobile
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.mchnt_id:
            if hasattr(self.mchnt_id, 'to_alipay_dict'):
                params['mchnt_id'] = self.mchnt_id.to_alipay_dict()
            else:
                params['mchnt_id'] = self.mchnt_id
        if self.original_isv_appid:
            if hasattr(self.original_isv_appid, 'to_alipay_dict'):
                params['original_isv_appid'] = self.original_isv_appid.to_alipay_dict()
            else:
                params['original_isv_appid'] = self.original_isv_appid
        if self.original_isv_mobile:
            if hasattr(self.original_isv_mobile, 'to_alipay_dict'):
                params['original_isv_mobile'] = self.original_isv_mobile.to_alipay_dict()
            else:
                params['original_isv_mobile'] = self.original_isv_mobile
        if self.original_isv_name:
            if hasattr(self.original_isv_name, 'to_alipay_dict'):
                params['original_isv_name'] = self.original_isv_name.to_alipay_dict()
            else:
                params['original_isv_name'] = self.original_isv_name
        if self.original_isv_pid:
            if hasattr(self.original_isv_pid, 'to_alipay_dict'):
                params['original_isv_pid'] = self.original_isv_pid.to_alipay_dict()
            else:
                params['original_isv_pid'] = self.original_isv_pid
        if self.out_parking_id:
            if hasattr(self.out_parking_id, 'to_alipay_dict'):
                params['out_parking_id'] = self.out_parking_id.to_alipay_dict()
            else:
                params['out_parking_id'] = self.out_parking_id
        if self.parking_address:
            if hasattr(self.parking_address, 'to_alipay_dict'):
                params['parking_address'] = self.parking_address.to_alipay_dict()
            else:
                params['parking_address'] = self.parking_address
        if self.parking_end_time:
            if hasattr(self.parking_end_time, 'to_alipay_dict'):
                params['parking_end_time'] = self.parking_end_time.to_alipay_dict()
            else:
                params['parking_end_time'] = self.parking_end_time
        if self.parking_fee_description:
            if hasattr(self.parking_fee_description, 'to_alipay_dict'):
                params['parking_fee_description'] = self.parking_fee_description.to_alipay_dict()
            else:
                params['parking_fee_description'] = self.parking_fee_description
        if self.parking_fee_description_img:
            if hasattr(self.parking_fee_description_img, 'to_alipay_dict'):
                params['parking_fee_description_img'] = self.parking_fee_description_img.to_alipay_dict()
            else:
                params['parking_fee_description_img'] = self.parking_fee_description_img
        if self.parking_id:
            if hasattr(self.parking_id, 'to_alipay_dict'):
                params['parking_id'] = self.parking_id.to_alipay_dict()
            else:
                params['parking_id'] = self.parking_id
        if self.parking_lot_type:
            if hasattr(self.parking_lot_type, 'to_alipay_dict'):
                params['parking_lot_type'] = self.parking_lot_type.to_alipay_dict()
            else:
                params['parking_lot_type'] = self.parking_lot_type
        if self.parking_mobile:
            if hasattr(self.parking_mobile, 'to_alipay_dict'):
                params['parking_mobile'] = self.parking_mobile.to_alipay_dict()
            else:
                params['parking_mobile'] = self.parking_mobile
        if self.parking_name:
            if hasattr(self.parking_name, 'to_alipay_dict'):
                params['parking_name'] = self.parking_name.to_alipay_dict()
            else:
                params['parking_name'] = self.parking_name
        if self.parking_number:
            if hasattr(self.parking_number, 'to_alipay_dict'):
                params['parking_number'] = self.parking_number.to_alipay_dict()
            else:
                params['parking_number'] = self.parking_number
        if self.parking_poiid:
            if hasattr(self.parking_poiid, 'to_alipay_dict'):
                params['parking_poiid'] = self.parking_poiid.to_alipay_dict()
            else:
                params['parking_poiid'] = self.parking_poiid
        if self.parking_start_time:
            if hasattr(self.parking_start_time, 'to_alipay_dict'):
                params['parking_start_time'] = self.parking_start_time.to_alipay_dict()
            else:
                params['parking_start_time'] = self.parking_start_time
        if self.parking_type:
            if hasattr(self.parking_type, 'to_alipay_dict'):
                params['parking_type'] = self.parking_type.to_alipay_dict()
            else:
                params['parking_type'] = self.parking_type
        if self.pay_type:
            if hasattr(self.pay_type, 'to_alipay_dict'):
                params['pay_type'] = self.pay_type.to_alipay_dict()
            else:
                params['pay_type'] = self.pay_type
        if self.payment_mode:
            if hasattr(self.payment_mode, 'to_alipay_dict'):
                params['payment_mode'] = self.payment_mode.to_alipay_dict()
            else:
                params['payment_mode'] = self.payment_mode
        if self.shopingmall_id:
            if hasattr(self.shopingmall_id, 'to_alipay_dict'):
                params['shopingmall_id'] = self.shopingmall_id.to_alipay_dict()
            else:
                params['shopingmall_id'] = self.shopingmall_id
        if self.sum_space:
            if hasattr(self.sum_space, 'to_alipay_dict'):
                params['sum_space'] = self.sum_space.to_alipay_dict()
            else:
                params['sum_space'] = self.sum_space
        if self.support_after_pay:
            if hasattr(self.support_after_pay, 'to_alipay_dict'):
                params['support_after_pay'] = self.support_after_pay.to_alipay_dict()
            else:
                params['support_after_pay'] = self.support_after_pay
        if self.time_out:
            if hasattr(self.time_out, 'to_alipay_dict'):
                params['time_out'] = self.time_out.to_alipay_dict()
            else:
                params['time_out'] = self.time_out
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarParkingParkinglotinfoUpdateModel()
        if 'agent_id' in d:
            o.agent_id = d['agent_id']
        if 'business_isv' in d:
            o.business_isv = d['business_isv']
        if 'city_id' in d:
            o.city_id = d['city_id']
        if 'contact_alipay' in d:
            o.contact_alipay = d['contact_alipay']
        if 'contact_email' in d:
            o.contact_email = d['contact_email']
        if 'contact_mobile' in d:
            o.contact_mobile = d['contact_mobile']
        if 'contact_name' in d:
            o.contact_name = d['contact_name']
        if 'contact_tel' in d:
            o.contact_tel = d['contact_tel']
        if 'contact_weixin' in d:
            o.contact_weixin = d['contact_weixin']
        if 'equipment_name' in d:
            o.equipment_name = d['equipment_name']
        if 'is_support_invoice' in d:
            o.is_support_invoice = d['is_support_invoice']
        if 'isv_mobile' in d:
            o.isv_mobile = d['isv_mobile']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'mchnt_id' in d:
            o.mchnt_id = d['mchnt_id']
        if 'original_isv_appid' in d:
            o.original_isv_appid = d['original_isv_appid']
        if 'original_isv_mobile' in d:
            o.original_isv_mobile = d['original_isv_mobile']
        if 'original_isv_name' in d:
            o.original_isv_name = d['original_isv_name']
        if 'original_isv_pid' in d:
            o.original_isv_pid = d['original_isv_pid']
        if 'out_parking_id' in d:
            o.out_parking_id = d['out_parking_id']
        if 'parking_address' in d:
            o.parking_address = d['parking_address']
        if 'parking_end_time' in d:
            o.parking_end_time = d['parking_end_time']
        if 'parking_fee_description' in d:
            o.parking_fee_description = d['parking_fee_description']
        if 'parking_fee_description_img' in d:
            o.parking_fee_description_img = d['parking_fee_description_img']
        if 'parking_id' in d:
            o.parking_id = d['parking_id']
        if 'parking_lot_type' in d:
            o.parking_lot_type = d['parking_lot_type']
        if 'parking_mobile' in d:
            o.parking_mobile = d['parking_mobile']
        if 'parking_name' in d:
            o.parking_name = d['parking_name']
        if 'parking_number' in d:
            o.parking_number = d['parking_number']
        if 'parking_poiid' in d:
            o.parking_poiid = d['parking_poiid']
        if 'parking_start_time' in d:
            o.parking_start_time = d['parking_start_time']
        if 'parking_type' in d:
            o.parking_type = d['parking_type']
        if 'pay_type' in d:
            o.pay_type = d['pay_type']
        if 'payment_mode' in d:
            o.payment_mode = d['payment_mode']
        if 'shopingmall_id' in d:
            o.shopingmall_id = d['shopingmall_id']
        if 'sum_space' in d:
            o.sum_space = d['sum_space']
        if 'support_after_pay' in d:
            o.support_after_pay = d['support_after_pay']
        if 'time_out' in d:
            o.time_out = d['time_out']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CardPromoDO(object):

    def __init__(self):
        self._card_id = None
        self._card_level = None
        self._limit = None
        self._promo_icon = None
        self._promo_title = None
        self._received = None
        self._target_mark_count = None

    @property
    def card_id(self):
        return self._card_id

    @card_id.setter
    def card_id(self, value):
        self._card_id = value
    @property
    def card_level(self):
        return self._card_level

    @card_level.setter
    def card_level(self, value):
        self._card_level = value
    @property
    def limit(self):
        return self._limit

    @limit.setter
    def limit(self, value):
        self._limit = value
    @property
    def promo_icon(self):
        return self._promo_icon

    @promo_icon.setter
    def promo_icon(self, value):
        self._promo_icon = value
    @property
    def promo_title(self):
        return self._promo_title

    @promo_title.setter
    def promo_title(self, value):
        self._promo_title = value
    @property
    def received(self):
        return self._received

    @received.setter
    def received(self, value):
        self._received = value
    @property
    def target_mark_count(self):
        return self._target_mark_count

    @target_mark_count.setter
    def target_mark_count(self, value):
        self._target_mark_count = value


    def to_alipay_dict(self):
        params = dict()
        if self.card_id:
            if hasattr(self.card_id, 'to_alipay_dict'):
                params['card_id'] = self.card_id.to_alipay_dict()
            else:
                params['card_id'] = self.card_id
        if self.card_level:
            if hasattr(self.card_level, 'to_alipay_dict'):
                params['card_level'] = self.card_level.to_alipay_dict()
            else:
                params['card_level'] = self.card_level
        if self.limit:
            if hasattr(self.limit, 'to_alipay_dict'):
                params['limit'] = self.limit.to_alipay_dict()
            else:
                params['limit'] = self.limit
        if self.promo_icon:
            if hasattr(self.promo_icon, 'to_alipay_dict'):
                params['promo_icon'] = self.promo_icon.to_alipay_dict()
            else:
                params['promo_icon'] = self.promo_icon
        if self.promo_title:
            if hasattr(self.promo_title, 'to_alipay_dict'):
                params['promo_title'] = self.promo_title.to_alipay_dict()
            else:
                params['promo_title'] = self.promo_title
        if self.received:
            if hasattr(self.received, 'to_alipay_dict'):
                params['received'] = self.received.to_alipay_dict()
            else:
                params['received'] = self.received
        if self.target_mark_count:
            if hasattr(self.target_mark_count, 'to_alipay_dict'):
                params['target_mark_count'] = self.target_mark_count.to_alipay_dict()
            else:
                params['target_mark_count'] = self.target_mark_count
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CardPromoDO()
        if 'card_id' in d:
            o.card_id = d['card_id']
        if 'card_level' in d:
            o.card_level = d['card_level']
        if 'limit' in d:
            o.limit = d['limit']
        if 'promo_icon' in d:
            o.promo_icon = d['promo_icon']
        if 'promo_title' in d:
            o.promo_title = d['promo_title']
        if 'received' in d:
            o.received = d['received']
        if 'target_mark_count' in d:
            o.target_mark_count = d['target_mark_count']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoPrinterStatusNotifyModel(object):

    def __init__(self):
        self._eprint_sign = None
        self._machine_code = None
        self._oauth_type = None
        self._online = None
        self._push_time = None

    @property
    def eprint_sign(self):
        return self._eprint_sign

    @eprint_sign.setter
    def eprint_sign(self, value):
        self._eprint_sign = value
    @property
    def machine_code(self):
        return self._machine_code

    @machine_code.setter
    def machine_code(self, value):
        self._machine_code = value
    @property
    def oauth_type(self):
        return self._oauth_type

    @oauth_type.setter
    def oauth_type(self, value):
        self._oauth_type = value
    @property
    def online(self):
        return self._online

    @online.setter
    def online(self, value):
        self._online = value
    @property
    def push_time(self):
        return self._push_time

    @push_time.setter
    def push_time(self, value):
        self._push_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.eprint_sign:
            if hasattr(self.eprint_sign, 'to_alipay_dict'):
                params['eprint_sign'] = self.eprint_sign.to_alipay_dict()
            else:
                params['eprint_sign'] = self.eprint_sign
        if self.machine_code:
            if hasattr(self.machine_code, 'to_alipay_dict'):
                params['machine_code'] = self.machine_code.to_alipay_dict()
            else:
                params['machine_code'] = self.machine_code
        if self.oauth_type:
            if hasattr(self.oauth_type, 'to_alipay_dict'):
                params['oauth_type'] = self.oauth_type.to_alipay_dict()
            else:
                params['oauth_type'] = self.oauth_type
        if self.online:
            if hasattr(self.online, 'to_alipay_dict'):
                params['online'] = self.online.to_alipay_dict()
            else:
                params['online'] = self.online
        if self.push_time:
            if hasattr(self.push_time, 'to_alipay_dict'):
                params['push_time'] = self.push_time.to_alipay_dict()
            else:
                params['push_time'] = self.push_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoPrinterStatusNotifyModel()
        if 'eprint_sign' in d:
            o.eprint_sign = d['eprint_sign']
        if 'machine_code' in d:
            o.machine_code = d['machine_code']
        if 'oauth_type' in d:
            o.oauth_type = d['oauth_type']
        if 'online' in d:
            o.online = d['online']
        if 'push_time' in d:
            o.push_time = d['push_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InstalmentPlanTuitionDTO import InstalmentPlanTuitionDTO
from alipay.aop.api.domain.RechargeConfigTuitionDTO import RechargeConfigTuitionDTO


class RechargeOrderTuitionDTO(object):

    def __init__(self):
        self._create_time = None
        self._finished_periods = None
        self._order_id = None
        self._partner_id = None
        self._periods = None
        self._plans = None
        self._recharge_config = None
        self._refund_type = None
        self._smid = None
        self._status = None
        self._total_amount = None
        self._trade_no = None
        self._user_display_name = None
        self._user_id = None

    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, value):
        self._create_time = value
    @property
    def finished_periods(self):
        return self._finished_periods

    @finished_periods.setter
    def finished_periods(self, value):
        self._finished_periods = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def periods(self):
        return self._periods

    @periods.setter
    def periods(self, value):
        self._periods = value
    @property
    def plans(self):
        return self._plans

    @plans.setter
    def plans(self, value):
        if isinstance(value, list):
            self._plans = list()
            for i in value:
                if isinstance(i, InstalmentPlanTuitionDTO):
                    self._plans.append(i)
                else:
                    self._plans.append(InstalmentPlanTuitionDTO.from_alipay_dict(i))
    @property
    def recharge_config(self):
        return self._recharge_config

    @recharge_config.setter
    def recharge_config(self, value):
        if isinstance(value, RechargeConfigTuitionDTO):
            self._recharge_config = value
        else:
            self._recharge_config = RechargeConfigTuitionDTO.from_alipay_dict(value)
    @property
    def refund_type(self):
        return self._refund_type

    @refund_type.setter
    def refund_type(self, value):
        self._refund_type = value
    @property
    def smid(self):
        return self._smid

    @smid.setter
    def smid(self, value):
        self._smid = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def user_display_name(self):
        return self._user_display_name

    @user_display_name.setter
    def user_display_name(self, value):
        self._user_display_name = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.create_time:
            if hasattr(self.create_time, 'to_alipay_dict'):
                params['create_time'] = self.create_time.to_alipay_dict()
            else:
                params['create_time'] = self.create_time
        if self.finished_periods:
            if hasattr(self.finished_periods, 'to_alipay_dict'):
                params['finished_periods'] = self.finished_periods.to_alipay_dict()
            else:
                params['finished_periods'] = self.finished_periods
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.periods:
            if hasattr(self.periods, 'to_alipay_dict'):
                params['periods'] = self.periods.to_alipay_dict()
            else:
                params['periods'] = self.periods
        if self.plans:
            if isinstance(self.plans, list):
                for i in range(0, len(self.plans)):
                    element = self.plans[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.plans[i] = element.to_alipay_dict()
            if hasattr(self.plans, 'to_alipay_dict'):
                params['plans'] = self.plans.to_alipay_dict()
            else:
                params['plans'] = self.plans
        if self.recharge_config:
            if hasattr(self.recharge_config, 'to_alipay_dict'):
                params['recharge_config'] = self.recharge_config.to_alipay_dict()
            else:
                params['recharge_config'] = self.recharge_config
        if self.refund_type:
            if hasattr(self.refund_type, 'to_alipay_dict'):
                params['refund_type'] = self.refund_type.to_alipay_dict()
            else:
                params['refund_type'] = self.refund_type
        if self.smid:
            if hasattr(self.smid, 'to_alipay_dict'):
                params['smid'] = self.smid.to_alipay_dict()
            else:
                params['smid'] = self.smid
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        if self.user_display_name:
            if hasattr(self.user_display_name, 'to_alipay_dict'):
                params['user_display_name'] = self.user_display_name.to_alipay_dict()
            else:
                params['user_display_name'] = self.user_display_name
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RechargeOrderTuitionDTO()
        if 'create_time' in d:
            o.create_time = d['create_time']
        if 'finished_periods' in d:
            o.finished_periods = d['finished_periods']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'periods' in d:
            o.periods = d['periods']
        if 'plans' in d:
            o.plans = d['plans']
        if 'recharge_config' in d:
            o.recharge_config = d['recharge_config']
        if 'refund_type' in d:
            o.refund_type = d['refund_type']
        if 'smid' in d:
            o.smid = d['smid']
        if 'status' in d:
            o.status = d['status']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        if 'user_display_name' in d:
            o.user_display_name = d['user_display_name']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o


